OC.L10N.register(
    "spreed",
    {
    "a conversation" : "egy beszélgetés",
    "(Duration %s)" : "(Időtartam: %s)",
    "You attended a call with {user1}" : "Részt vett egy hívásban vele: {user1}",
    "_%n guest_::_%n guests_" : ["%n vendég","%n vendég"],
    "You attended a call with {user1} and {user2}" : "Részt vett egy hívásban velük: {user1} és {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Részt vett egy hívásban velük: {user1}, {user2} és {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Részt vett egy hívásban velük: {user1}, {user2}, {user3} és {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Részt vett egy hívásban velük: {user1}, {user2}, {user3}, {user4} és {user5}",
    "_%n other_::_%n others_" : ["még %n emberrel","még %n emberrel"],
    "{actor} invited you to {call}" : "{actor} meghívta ide: {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Meghívták egy <strong>beszélgetésbe</strong>, vagy <strong>hívása</strong> volt",
    "Other activities" : "Egyéb tevékenységek",
    "Talk" : "Beszélgetés",
    "Guest" : "Vendég",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Üdvözöljük a Nextcloud Beszélgetésben!\nEbben a beszélgetésben tájékoztatást kap a Nextcloud Beszélgetés új funkcióiról.",
    "## New in Talk %s" : "## A Beszélgetés %s újdonságai",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- A Microsoft Edge és a Safari mostantól használható hang- és videohívásokhoz",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- A négyszemközti beszélgetések most már tartósak, és nem lehet véletlenül csoportos beszélgetéssé alakítani őket. Emellett ha egy résztvevő elhagyja a beszélgetést, akkor most már nem kerül automatikusan törlésre. Csak ha mindkét fél elhagyja a beszélgetést, akkor kerül törlésre a kiszolgálóról",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Most már értesítheti az összes résztvevőt az *@all* beírásával a csevegésbe",
    "- With the \"arrow-up\" key you can repost your last message" : "- A „felfele nyíl” billentyűvel újraküldheti az előző üzenetét",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- A Beszélgetés most már kezel parancsokat, küldje el a „/help” üzenetet a csevegésbe, és nézze meg, hogy a rendszergazda állított-e be",
    "- With projects you can create quick links between conversations, files and other items" : "- A projektekkel gyors hivatkozásokat hozhat létre beszélgetések, fájlok és egyéb elemek között",
    "- You can now mention guests in the chat" : "- Most már megemlíthet vendégeket a csevegésben",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- A beszélgetéseknek most már lehet várójuk. Ez lehetővé teszi a moderátoroknak, hogy csatlakozzanak a csevegéshez, és már hívják egymást a találkozó előkészítéséhez, míg a felhasználóknak és a vendégeknek várniuk kell",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Most már közvetlenül válaszolhat az üzenetekre, így a többi felhasználónak kontextusba helyezheti, miről szól az üzenete",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- A beszélgetések és a résztvevők keresése mostantól a meglévő beszélgetéseket is kiszűri, így sokkal könnyebb megtalálni a korábbi beszélgetéseket",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Mostantól, hozzáadhat egyéni felhasználói csoportokat a beszélgetésekhez, amennyiben a CIrcles alkalmazás telepítve van",
    "- Check out the new grid and call view" : "- Nézze meg az új rács és hívás nézeteket",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Mostantól közvetlenül feltöltheti az eszközéről a fájlokat, és áthúzhatja őket a csevegésbe",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- A megosztott fájlok most a megtekintő alkalmazásokkal közvetlenül a chat nézetben nyílnak meg",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Mostantól a felső sáv egységes keresőben kereshet csevegéseket és üzeneteket",
    "- Spice up your messages with emojis from the emoji picker" : "- Fűszerezze üzeneteit hangulatjelekkel az emoji kiválasztóból",
    "- You can now change your camera and microphone while being in a call" : "- Most már megváltoztathatja a fényképezőgépet és a mikrofont hívás közben",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Adjon néhány beszélgetést a leírásához, és nyissa meg, hogy a bejelentkezett felhasználók megtalálhassák és csatlakozhassanak",
    "- See a read status and send failed messages again" : "- Lásd az olvasási állapotot és küldje el ismét a sikertelen üzeneteket",
    "- Raise your hand in a call with the R key" : "- Emelje fel a kezét hívás közben az R gombbal",
    "- Join the same conversation and call from multiple devices" : "- Csatlakozzon ugyanazon beszélgetéshez és híváshoz több eszközzel",
    "- Send voice messages, share your location or contact details" : "- Küldjön hangüzeneteket, ossza meg a helyét vagy névjegyadatait",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Adjon csoportokat egy beszélgetéshez, és az új csoporttagok automatikusan hozzáadásra kerülnek résztvevőként",
    "- A preview of your audio and video is shown before joining a call" : "- Megjelenik a hang és a videó előnézete, mielőtt csatlakozik a híváshoz",
    "- You can now blur your background in the newly designed call view" : "- Már elhomályosíthatja a hátteret az újratervezett hívásnézetben",
    "- Moderators can now assign general and individual permissions to participants" : "- A moderátorok most már általános és egyéni jogosultságokat is hozzárendelhetnek a résztvevőkhöz",
    "- You can now react to chat messages" : "- Most már reagálhat a csevegőüzenetekre",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Az oldalsávban megtalálhatja a legutóbb megosztott elemeket",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Használjon egy szavazást, hogy összegyűjtse a többiek véleményét, vagy hogy megegyezzenek egy dátumban",
    "- Configure an expiration time for chat messages" : "- Állítson be elévülési időt a csevegőüzenetekhez",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Indítson hívásokat anélkül, hogy értesítené a nagy beszélgetésekben lévőket. A hívás elindítása után külön hívásértesítéseket küldhet.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Küldjön csevegőüzenetet a címzettek értesítése nélkül, ha nem sürgős",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Az emodzsik mostantól automatikusan kiegészíthetők egy „:” begépelésével",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Különböző elemek hivatkozása az új okos kiválasztóval, egy „/” begépelésével",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- A moderátorok mostantól szobabontást hozhatnak létre (a nagy teljesítményű háttérrendszert igényli)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- A hívások mostantól felvehetőek (a nagy teljesítményű háttérrendszert igényli)",
    "- Conversations can now have an avatar or emoji as icon" : "- A beszélgetéseknek most már lehet profilképük vagy emodzsit használó ikonjuk",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- A videóhívásoknál a virtuális hátterek már elérhetők az elhomályosított háttér mellett",
    "- Reactions are now available during calls" : "- A reakciók most már hívás közben is elérhetők",
    "- Typing indicators show which users are currently typing a message" : "- Gépelésjelzők mutatják, ha a felhasználók épp gépelnek",
    "- Groups can now be mentioned in chats" : "- A csoportok most már megemlíthetők a csevegésekben",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- A hívásrögzítések automatikusan leiratozásra kerülnek, ha van leiratozási szolgáltató alkalmazás regisztrálva",
    "- Chat messages can be translated if a translation provider app is registered" : "- A csevegőüzenet lefordíthatók, ha van fordítási szolgáltató alkalmazás regisztrálva",
    "- **Markdown** can now be used in _chat_ messages" : "- A **Markdown** most már használható a _csevegőüzenetekben_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- A webhookok már elérhetőek a botok megvalósításához. További részletekért tekintse meg a dokumentációt: https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Időzítő beállítsa egy csevegőüzenetnél, hogy később újra értesítést kapjon róla",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- **Saját jegyzet** a beszélgetésekben, hogy jegyzeteljen és információt osszon meg az eszközei közt",
    "- Captions allow to send a message with a file at the same time" : "- Feliratok, hogy egyszerre fájlt és üzenetet is lehessen küldeni",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- A beszélő videója most már látható képernyőmegosztás közben is, és a hívásreakciók animálva vannak",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Az üzeneteket 6 óráig szerkeszthetik a bejelentkezett szerzők és moderátorok",
    "- Unsent message drafts are now saved in your browser" : "- A mentetlen vázlatok most már mentésre kerülnek a böngészőben",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- A szöveges csevegés most már más Beszélgetés kiszolgálókkal föderálva is elérhető",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- A moderátorok most már úgy is kitilthatnak fiókokat és vendégeket, hogy nem tudnak újból csatlakozni",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Most már látszódnak a következő hívások az összekapcsolt naptáreseményekből, és a helyettesítések is megjelennek a beszélgetésekben",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- A hívások most már föderálhatóak más Beszélgetés-kiszolgálókkal (Nagy teljesítményű háttérrendszert igényel)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Bemutatkozik az asztali Nextcloud Beszélgetés alkalmazás Windowsra, macOS-re és Linuxra: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- A hívásfelvételek és a csevegések olvasatlan üzeneteinek összefoglalása a Nextcloud Asszisztens használatával",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Továbbfejlesztett találkozók az e-mail-címmel meghívott vendégek felismerésével, résztvevőlisták importálásával, szavazásvázlatokkal és a hívások résztvevői listájának letöltésével",
    "- Archive conversations to stay focused" : "- Beszélgetések archiválása, hogy fókuszált maradjon",
    "- Schedule a meeting into your calendar from within a conversation" : "- Találkozó ütemezése a naptárába közvetlenül egy beszélgetésből",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Üzenetek keresése a jelenlegi beszélgetésben közvetlenül a jobb oldali oldalsávból",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- További beszélgetések áttekintése az első pillantáskor, az új kompakt listának köszönhetően (a Beszélgetés beállításaiban engedélyezhető)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- A találkozók beszélgetései most már szinkronizálják a címet és a leírást a naptárból, és szűrő rejti őket addig, amíg nem közeledik a kezdetük",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Beszélgetések megjelelölése bizalmasként az értesítési beállításokban, hogy ne jelenjen meg üzenettartalom a beszélgetések és az értesítések közt",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Hogy „Ne zavarjanak” állapotban is megkapja a leküldéses értesítéseket, jelölje fontosnak a beszélgetéseket",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Egyéb résztvevők hozzáadása a négyszemközti beszélgetésekhez, amely röptében új csoportos hívást hoz létre",
    "- Use threads to keep your chat and discussions organized" : "- Szálak használata a beszélgetések és témák szervezetten tartásához",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Elérhető az élő leiratozás a hívások során (az élő leiratozási ExApp, és a Nagy teljesítményű háttérrendszer szükséges hozzá)",
    "- Moderators can now pin messages so they are kept at the top" : "- A moderátorok most már kitűzhetnek bejegyzéseket, így felül maradnak",
    "- Schedule a message to send it at a later time" : "- Üzenet ütemezése későbbi elküldésre",
    "_All %n participant_::_All %n participants_" : ["Mind a(z) %n résztvevő","Mind a(z) %n résztvevő"],
    "Talk updates ✅" : "Beszélgetés frissítések ✅",
    "Reaction deleted by author" : "A reakciót törölte a szerző",
    "{actor} created the conversation" : "{actor} létrehozta a beszélgetést",
    "You created the conversation" : "Beszélgetést hozott létre",
    "System created the conversation" : "A rendszer hozta létre a beszélgetést",
    "An administrator created the conversation" : "Egy rendszergazda létrehozta a beszélgetést",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} átnevezte a beszélgetést erről: „%1$s”, erre: „%2$s”",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Átnevezte a beszélgetést erről: „%1$s”, erre: „%2$s”",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Egy rendszergazda átnevezte a beszélgetést erről: „%1$s”, erre: „%2$s”",
    "{actor} set the description" : "{actor} beállította a leírást",
    "You set the description" : "Beállította a leírást",
    "An administrator set the description" : "Egy rendszergazda beállította a leírást",
    "{actor} removed the description" : "{actor} eltávolította a leírást",
    "You removed the description" : "Eltávolította a leírást",
    "An administrator removed the description" : "Egy rendszergazda eltávolította a leírást",
    "You started a silent call" : "Néma hívást indított",
    "Outgoing silent call" : "Folyamatban lévő néma hívás",
    "{actor} started a silent call" : "{actor} néma hívást indított",
    "Incoming silent call" : "Bejövő néma hívás",
    "You started a call" : "Hívást indított",
    "Outgoing call" : "Kimenő hívás",
    "{actor} started a call" : "{actor} hívást indított",
    "Incoming call" : "Bejövő hívás",
    "{actor} joined the call" : "{actor} bekapcsolódott a hívásba",
    "You joined the call" : "Csatlakozott a híváshoz",
    "{actor} left the call" : "{actor} elhagyta a hívást",
    "You left the call" : "Kilépett a hívásból",
    "{actor} unlocked the conversation" : "{actor} feloldotta a beszélgetést",
    "You unlocked the conversation" : "Feloldotta a beszélgetést",
    "An administrator unlocked the conversation" : "Egy rendszergazda feloldotta a beszélgetést",
    "{actor} locked the conversation" : "{actor} zárolta a beszélgetést",
    "You locked the conversation" : "Zárolta a beszélgetést",
    "An administrator locked the conversation" : "A beszélgetést egy rendszergazda zárolta",
    "{actor} limited the conversation to the current participants" : "{actor} a beszélgetést a jelenlegi résztvevőkre korlátozta",
    "You limited the conversation to the current participants" : "A beszélgetést a jelenlegi résztvevőkre korlátozta",
    "An administrator limited the conversation to the current participants" : "Egy rendszergazda a beszélgetést a jelenlegi résztvevőkre korlátozta",
    "{actor} opened the conversation to registered users" : "{actor} megnyitotta beszélgetést a regisztrált felhasználók számára",
    "You opened the conversation to registered users" : "Megnyitotta beszélgetést a regisztrált felhasználók számára",
    "An administrator opened the conversation to registered users" : "Egy rendszergazda megnyitotta beszélgetést a regisztrált felhasználók számára",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} elindította a beszélgetést a regisztrált és a Vendégek alkalmazásban létrehozott felhasználók számára",
    "You opened the conversation to registered users and users created with the Guests app" : "Elindította a beszélgetést a regisztrált és a Vendégek alkalmazásban létrehozott felhasználók számára",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Egy rendszergazda elindította a beszélgetést a regisztrált és a Vendégek alkalmazásban létrehozott felhasználók számára",
    "The conversation is now open to everyone" : "A beszélgetés most már mindenki számára nyitva áll",
    "{actor} opened the conversation to everyone" : "{actor} megnyitotta beszélgetést mindenki számára",
    "You opened the conversation to everyone" : "Megnyitotta beszélgetést mindenki számára",
    "{actor} restricted the conversation to moderators" : "{actor} a moderátorokra korlátozta a beszélgetést",
    "You restricted the conversation to moderators" : "A moderátorokra korlátozta a beszélgetést",
    "{actor} started breakout rooms" : "{actor} elindította a szobabontást",
    "You started breakout rooms" : "Elindította a szobabontást",
    "{actor} stopped breakout rooms" : "{actor} leállította a szobabontást",
    "You stopped breakout rooms" : "Leállította a szobabontást",
    "{actor} allowed guests" : "{actor} engedélyezte a vendégeket",
    "You allowed guests" : "Engedélyezte a vendégeket",
    "An administrator allowed guests" : "Egy rendszergazda engedélyezte a vendégeket",
    "{actor} disallowed guests" : "{actor} letiltotta a vendégeket",
    "You disallowed guests" : "Letiltotta a vendégeket",
    "An administrator disallowed guests" : "Egy rendszergazda letiltotta a vendégeket",
    "{actor} set a password" : "{actor} jelszót állított be",
    "You set a password" : "Jelszót állított be",
    "An administrator set a password" : "Egy rendszergazda jelszót állított be",
    "{actor} removed the password" : "{actor} eltávolította a jelszót",
    "You removed the password" : "Eltávolította a jelszót",
    "An administrator removed the password" : "Egy rendszergazda eltávolította a jelszót",
    "{actor} added {user}" : "{actor} hozzáadta: {user}",
    "You joined the conversation" : "Csatlakozott a beszélgetéshez",
    "{actor} joined the conversation" : "{actor} csatlakozott a beszélgetéshez",
    "You added {user}" : "Hozzáadta: {user}",
    "{actor} added you" : "{actor} hozzáadta Önt",
    "An administrator added you" : "A rendszergazda hozzáadta Önt",
    "An administrator added {user}" : "A rendszergazda hozzáadta {user} felhasználót",
    "You left the conversation" : "Elhagyta a beszélgetést",
    "{actor} left the conversation" : "{actor} elhagyta a beszélgetést",
    "{actor} removed {user}" : "{actor} eltávolította: {user}",
    "You removed {user}" : "Eltávolította: {user}",
    "{actor} removed you" : "{actor} eltávolította",
    "An administrator removed you" : "Egy rendszergazda eltávolította Önt",
    "An administrator removed {user}" : "Egy rendszergazda eltávolította {user} felhasználót",
    "{actor} invited {federated_user}" : "{actor} meghívta: {federated_user}",
    "You invited {federated_user}" : "Meghívta: {federated_user}",
    "You accepted the invitation" : "Elfogadta a meghívást",
    "{actor} invited you" : "{actor} meghívta",
    "An administrator invited you" : "Egy rendszergazda meghívta",
    "An administrator invited {federated_user}" : "Egy rendszergazda meghívta: {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} elfogadta a meghívást",
    "{actor} removed {federated_user}" : "{actor} eltávolította: {federated_user}",
    "You removed {federated_user}" : "Eltávolította: {federated_user}",
    "You declined the invitation" : "Elutasította a meghívást",
    "An administrator removed {federated_user}" : "Egy rendszergazda eltávolította {federated_user} felhasználót",
    "{federated_user} declined the invitation" : "{federated_user} elfogadta a meghívást",
    "{actor} added group {group}" : "{actor} hozzáadta a(z) {group} csoportot",
    "You added group {group}" : "Hozzáadta a(z) {group} csoportot",
    "An administrator added group {group}" : "Egy rendszergazda hozzáadta a(z) {group} csoportot",
    "{actor} removed group {group}" : "{actor} eltávolította a(z) {group} csoportot",
    "You removed group {group}" : "Eltávolította a(z) {group} csoportot",
    "An administrator removed group {group}" : "Egy rendszergazda eltávolította a(z) {group} csoportot",
    "{actor} added team {circle}" : "{actor} hozzáadta a(z) {circle} csapatot",
    "You added team {circle}" : "Hozzáadta a(z) {circle} csapatot",
    "An administrator added team {circle}" : "Egy rendszergazda hozzáadta a(z) {circle} csapatot",
    "{actor} removed team {circle}" : "{actor} eltávolította a(z) {circle} csapatot",
    "You removed team {circle}" : "Eltávolította a(z) {circle} csapatot",
    "An administrator removed team {circle}" : "Egy rendszergazda eltávolította a(z) {circle} csapatot",
    "{actor} added {phone}" : "{actor} hozzáadta: {phone}",
    "You added {phone}" : "Hozzáadta: {phone}",
    "An administrator added {phone}" : "Egy rendszergazda hozzáadta: {phone}",
    "{actor} removed {phone}" : "{actor} eltávolította: {phone}",
    "You removed {phone}" : "Eltálvolította: {phone}",
    "An administrator removed {phone}" : "Egy rendszergazda eltávolította: {phone}",
    "{actor} promoted {user} to moderator" : "{actor} moderátorrá léptette elő: {user}",
    "You promoted {user} to moderator" : "Moderátorrá léptette elő: {user}",
    "{actor} promoted you to moderator" : "{actor} moderátorrá léptette elő",
    "An administrator promoted you to moderator" : "Egy rendszergazda moderátorrá léptette elő",
    "An administrator promoted {user} to moderator" : "Egy rendszergazda moderátorrá léptette elő {user} felhasználót",
    "{actor} demoted {user} from moderator" : "{actor} visszavonta {user} moderátori előléptetését",
    "You demoted {user} from moderator" : "Visszavonta {user} moderátori kinevezését",
    "{actor} demoted you from moderator" : "{actor} visszavonta a moderátori kinevezését",
    "An administrator demoted you from moderator" : "Egy rendszergazda visszavonta a moderátori kinevezését",
    "An administrator demoted {user} from moderator" : "Egy rendszergazda visszavonta {user} moderátori előléptetését",
    "{actor} shared a file which is no longer available" : "{actor} megosztott egy fájlt, ami már nem érhető el",
    "You shared a file which is no longer available" : "Megosztott egy fájlt, ami már nem érhető el",
    "File shares are currently not supported in federated conversations" : "A fájlmegosztások jelenleg nem támogatottak a föderált beszélgetésekben",
    "The shared location is malformed" : "A megosztott hely hibásan formázott",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} beállította a Matterbridge-dzset, hogy szinkronizálja ezt a beszélgetést más beszélgetésekkel",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Beállította a Matterbridge-dzset, hogy szinkronizálja ezt a beszélgetést más beszélgetésekkel",
    "{actor} created thread {title}" : "{actor} létrehozta a(z) {title} szálat",
    "You created thread {title}" : "Létrehozta a(z) {title} szálat",
    "{actor} renamed thread {title}" : "{actor} átnevezte a(z) {title} szálat",
    "You renamed thread {title}" : "Átnevezte a(z) {title} szálat",
    "{actor} updated the Matterbridge configuration" : "{actor} frissítette a Matterbridge beállításokat",
    "You updated the Matterbridge configuration" : "Frissítette a Matterbridge beállításokat",
    "{actor} removed the Matterbridge configuration" : "{actor} eltávolította a Matterbridge beállításokat",
    "You removed the Matterbridge configuration" : "Eltávolította a Matterbridge beállításokat",
    "{actor} started Matterbridge" : "{actor} elindította a Matterbridge-dzset",
    "You started Matterbridge" : "Elindította a Matterbridge-et",
    "{actor} stopped Matterbridge" : "{actor} leállította a Matterbridge-et",
    "You stopped Matterbridge" : "Leállította Matterbridge-et",
    "{actor} deleted a message" : "{actor} törölt egy üzenetet",
    "You deleted a message" : "Törölt egy üzenetet",
    "{actor} edited a message" : "{actor} szerkesztett egy üzenetet",
    "You edited a message" : "Szerkesztett egy üzenetet",
    "{actor} pinned a message" : "{actor} kitűzött egy üzenetet",
    "You pinned a message" : "Kitűzött egy üzenetet",
    "{actor} unpinned a message" : "{actor} megszüntette egy üzenet kitűzését",
    "Message was automatically unpinned" : "Az üzenet kitűzése automatikusan megszűnt",
    "You unpinned a message" : "Megszüntette egy üzenet kitűzését",
    "{actor} deleted a reaction" : "{actor} törölt egy reakciót",
    "You deleted a reaction" : "Törölt egy reakciót",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["%n hetesre állította az üzenetek elévülését","%n hetesre állította az üzenetek elévülését"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["%n naposra állította az üzenetek elévülését","%n naposra állította az üzenetek elévülését"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["%n órásra állította az üzenetek elévülését","%n órásra állította az üzenetek elévülését"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["%n percesre állította az üzenetek elévülését","%n percesre állította az üzenetek elévülését"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} %n hetesre állította az üzenetek elévülését","{actor} %n hetesre állította az üzenetek elévülését"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} %n naposra állította az üzenetek elévülését","{actor} %n naposra állította az üzenetek elévülését"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} %n órásra állította az üzenetek elévülését","{actor} %n órásra állította az üzenetek elévülését"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} %n percesre állította az üzenetek elévülését","{actor} %n percesre állította az üzenetek elévülését"],
    "{actor} disabled message expiration" : "{actor} kikapcsolta az üzenetek elévülését",
    "You disabled message expiration" : "Kikapcsolta az üzenetek elévülését",
    "{actor} cleared the history of the conversation" : "{actor} törölte a beszélgetés előzményeit",
    "You cleared the history of the conversation" : "Törölte a beszélgetés előzményeit",
    "{actor} set the conversation picture" : "{actor} beállította a beszélgetés képét",
    "You set the conversation picture" : "Beállította a beszélgetés képét",
    "{actor} removed the conversation picture" : "{actor} eltávolította a beszélgetés képét",
    "You removed the conversation picture" : "Eltávolította a beszélgetés képét",
    "{actor} ended the poll {poll}" : "{actor} befejezte a(z) {poll} szavazást",
    "You ended the poll {poll}" : "Befejezte a(z) {poll} szavazást",
    "{actor} started the video recording" : "{actor} elindította a videófelvételt",
    "You started the video recording" : "Elindította a videófelvételt",
    "{actor} stopped the video recording" : "{actor} leállította a videófelvételt",
    "You stopped the video recording" : "Leállította a videófelvételt",
    "{actor} started the audio recording" : "{actor} elindította a videófelvételt",
    "You started the audio recording" : "Elindította a videófelvételt",
    "{actor} stopped the audio recording" : "{actor} leállította a hangfelvételt",
    "You stopped the audio recording" : "Leállította a hangfelvételt",
    "The recording failed" : "A felvétel sikertelen",
    "Someone voted on the poll {poll}" : "Valaki szavazott a(z) {poll} szavazásban",
    "Message deleted by author" : "Az üzenetet a szerző törölte",
    "Message deleted by {actor}" : "{actor} törölte az üzenetet",
    "Message deleted by you" : "Törölte az üzenetet",
    "Deleted user" : "Törölt felhasználó",
    "Unknown number" : "Ismeretlen szám",
    "Administration" : "Adminisztráció",
    "System" : "Rendszer",
    "%s (guest)" : "%s (vendég)",
    "Missed call" : "Nem fogadott hívás",
    "Unanswered call" : "Nem megválaszolt hívás",
    "Call ended (Duration {duration})" : "A hívás véget ért (hossz: {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "A hívás a maximális híváshossz elérése miatt véget ért (hossz: {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} befejezte a hívást (hossz: {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["A hívás %n vendéggel a maximális híváshossz elérése miatt befejeződött (hossz: {duration})","A hívás %n vendéggel a maximális híváshossz elérése miatt befejeződött (hossz: {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["A hívás %n vendéggel befejeződött (hossz: {duration})","A hívás %n vendéggel befejeződött (hossz: {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} befejezte a hívást %n vendéggel (hossz: {duration})","{actor} befejezte a hívást %n vendéggel (hossz: {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "A hívás a következővel a maximális híváshossz elérése miatt befejeződött: {user1} (hossz: {duration})",
    "Call with {user1} ended (Duration {duration})" : "A hívás a következővel bejeződött: {user1} (hossz: {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} befejezte a hívást a következővel: {user1} (hossz: {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "A hívás a következőkkel a maximális híváshossz elérése miatt befejeződött: {user1} és {user2} (hossz: {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "A hívás a következőkkel befejeződött: {user1} és {user2} (hossz: {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} befejezte a hívást a következőkkel: {user1} és {user2} (Időtartam: {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "A hívás {user1}, {user2} és {user3} felhasználóval a maximális híváshossz elérése miatt befejeződött (hossz: {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "A hívás a következőkkel befejeződött: {user1}, {user2} és {user3} (hossz: {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} befejezte a hívást a következőkkel: {user1}, {user2} és {user3} (hossz: {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "A hívás a következőkkel a maximális híváshossz elérése miatt befejeződött: {user1}, {user2}, {user3} és {user4} (hossz: {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "A hívás a következőkkel befejeződött: {user1}, {user2}, {user3} és {user4} (hossz: {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} befejezte a hívást a következőkkel: {user1}, {user2}, {user3} és {user4} (Időtartam: {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "A hívás a következőkkel a maximális híváshossz elérése miatt befejeződött: {user1}, {user2}, {user3}, {user4} és {user5} (hossz: {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "A hívás a következőkkel befejeződött: {user1}, {user2}, {user3}, {user4} és {user5} (hossz: {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} befejezte a hívást a következőkkel: {user1}, {user2}, {user3}, {user4} és {user5} (hossz: {duration})",
    "Message of {user} in {conversation}" : "{user} üzenete a(z) {conversation} beszélgetésben",
    "Message of {user}" : "{user} üzenete",
    "Message of a deleted user in {conversation}" : "Egy törölt felhasználó üzenete a(z) {conversation} beszélgetésben",
    "Talk conversations" : "Beszélgetések",
    "Call %s" : "%s hívása",
    "An error occurred. Please contact your administrator." : "Hiba történt. Lépjen kapcsolatba a rendszergazdával.",
    "Storage quota exceeded" : "Tárhelykvóta túllépve",
    "File not found" : "A fájl nem található",
    "File is not shared, or shared but not with the user" : "A fájl nincs megosztva, vagy meg van, de nem a felhasználóval",
    "No account available to delete." : "Nincs törölhető fiók.",
    "Poll" : "Szavazás",
    "Password needs to be set" : "A jelszót meg kell adni",
    "Uploading the file failed" : "Nem sikerült feltölteni a fájlt",
    "No image file provided" : "Nincs képfájl megadva",
    "File is too big" : "A fájl túl nagy",
    "Invalid file provided" : "Érvénytelen fájl van megadva",
    "Invalid image" : "Érvénytelen kép",
    "Unknown filetype" : "Ismeretlen fájltípus",
    "Talk mentions" : "Beszélgetés említések",
    "More conversations" : "További beszélgetések",
    "Say hi to your friends and colleagues!" : "Köszönjön a barátainak és munkatársainak!",
    "No unread mentions" : "Nincsenek olvasatlan említések",
    "Call in progress" : "Hívás folyamatban",
    "You were mentioned" : "Megemlítették Önt",
    "Write to conversation" : "Írjon a beszélgetésbe",
    "Writes event information into a conversation of your choice" : "Beírja az esemény adatait egy választott beszélgetésbe",
    "Missing email field in header line" : "Hiányzó e-mail-mező a fejlécsorban",
    "Following lines are invalid: %s" : "A következő sorok érvénytelenek: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s meghívta a(z) „%2$s” beszélgetésbe.",
    "You were invited to conversation \"%s\"." : "Meghívták a(z) „%s” beszélgetésbe.",
    "Conversation invitation" : "Beszélgetés-meghívó",
    "Scheduled time" : "Ütemezett időpont",
    "Description" : "Leírás",
    "You can also dial-in via phone with the following details" : "Telefonon keresztül is be tudja tárcsázni a következő részleteket",
    "Dial-in information" : "Telefonos információk",
    "Meeting ID" : "Értekezlet azonosítója",
    "Your PIN" : "Az Ön PIN-kódja",
    "Click the button below to join the lobby now." : "Kattintson a lenti gombra a váróhoz való csatlakozáshoz.",
    "Click the link below to join the lobby now." : "Kattintson a lenti hivatkozásra a váróhoz való csatlakozáshoz.",
    "Join lobby for \"%s\"" : "Csatlakozás a(z) „%s” várójához",
    "Click the button below to join the conversation now." : "Kattintson a lenti gombra a beszélgetéshez való csatlakozáshoz.",
    "Click the link below to join the conversation now." : "Kattintson a lenti hivatkozásra a beszélgetéshez való csatlakozáshoz.",
    "Join \"%s\"" : "Csatlakozás ehhez: „%s”",
    "Meeting" : "Találkozó",
    "Password request: %s" : "Jelszókérés: %s",
    "Private conversation" : "Privát beszélgetés",
    "Deleted user (%s)" : "Törölt felhasználó (%s)",
    "Failed to upload call recording" : "A hívásfelvétel feltöltése sikertelen",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "A felvételi kiszolgáló nem tudta feltölteni a következő hívást: {call}. Vegye fel a kapcsolatot a rendszergazdákkal.",
    "Share to chat" : "Megosztás csevegésben",
    "Dismiss notification" : "Értesítés mellőzése",
    "Call recording now available" : "A hívásfelvétel már elérhető",
    "The recording for the call in {call} was uploaded to {file}." : "A(z) {call} hívás felvétele feltöltésre került ide: {file}.",
    "Transcript now available" : "A leiratozás elérhető",
    "The transcript for the call in {call} was uploaded to {file}." : "A(z) {call} hívás leirata feltöltésre került ide: {file}.",
    "Failed to transcript call recording" : "A hívásfelvétel leiratozása sikertelen",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "A kiszolgáló nem tudta leiratozni a(z) {call} hívás a következő helyre: {file}. Vegye fel a kapcsolatot a rendszergazdával.",
    "Call summary now available" : "A hívásösszefoglaló most már elérhető",
    "The summary for the call in {call} was uploaded to {file}." : "A(z) {call} hívásösszefoglalója ide lett feltöltve: {file}.",
    "Failed to summarize call recording" : "Nem sikerült összefoglalni a hívást",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "A kiszolgáló nem tudta összefoglalni a(z) {call} hívást itt: {file}. Lépjen kapcsolatba a rendszergazdákkal.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} meghívta, hogy csatlakozzon a(z) {roomName} szobához itt: {remoteServer}",
    "Accept" : "Elfogadás",
    "Decline" : "Elutasítás",
    "{user1} invited you to a federated conversation" : "{user1} meghívta egy föderált beszélgetésbe",
    "Someone reacted" : "Valaki reagált",
    "New message" : "Új üzenet",
    "Reminder" : "Emlékeztető",
    "Someone mentioned you" : "Valaki megemlítette",
    "Notification" : "Értesítés",
    "Someone reacted in a private conversation" : "Valaki reagált egy privát beszélgetésben",
    "You received a message in a private conversation" : "Kapott egy üzenetet egy privát beszélgetésben",
    "Reminder in a private conversation" : "Emlékeztető egy privát beszélgetésben",
    "Someone mentioned you in a private conversation" : "Valaki megemlítette egy privát beszélgetésben",
    "Notification in a private conversation" : "Értesítés egy privát beszélgetésben",
    "Reminder: You in {call}" : "Emlékeztető: {call}",
    "Reminder: {user} in {call}" : "Emlékeztető: {user} {call}",
    "Reminder: Deleted user in {call}" : "Felhasználó törölve a következőben: {call}",
    "Reminder: {guest} (guest) in {call}" : "Emlékeztető: {guest} (vendég) itt: {call}",
    "Reminder: Guest in {call}" : "Emlékeztető: Vendég itt: {call}",
    "{user} reacted with {reaction}" : "{user} a következővel reagált: {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} a következővel reagált: {reaction} itt: {call}",
    "Deleted user reacted with {reaction} in {call}" : "Egy törölt felhasználó a következővel reagált: {reaction} itt: {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (vendég) ezzel reagált: {reaction}, ebben: {call}",
    "Guest reacted with {reaction} in {call}" : "Egy vendég ezzel reagált: {reaction} itt: {call}",
    "{user} in {call}" : "{user} itt: {call}",
    "Deleted user in {call}" : "Felhasználó törölve a következőben: {call}",
    "{guest} (guest) in {call}" : "{guest} (vendég) itt: {call}",
    "Guest in {call}" : "Vendég a(z) {call} hívásban",
    "{user} sent you a private message" : "{user} privát üzenetet küldött",
    "{user} sent a message in conversation {call}" : "{user} üzenetet küldött a(z) {call} beszélgetésben",
    "A deleted user sent a message in conversation {call}" : "Egy törölt felhasználó üzenetet küldött a(z) {call} beszélgetésben",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (vendég) üzenetet küldött a(z) {call} beszélgetésben",
    "A guest sent a message in conversation {call}" : "Egy vendég üzenetet küldött a(z) {call} beszélgetésben",
    "{user} replied to your private message" : "{user} válaszolt a privát üzenetére",
    "{user} replied to your message in conversation {call}" : "{user} válaszolt az üzenetedre a(z) {call} beszélgetésben",
    "A deleted user replied to your message in conversation {call}" : "Egy törölt felhasználó válaszolt az üzenetére a(z) {call} beszélgetésben",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (vendég) válaszolt az üzenetére a(z) {call} beszélgetésben",
    "A guest replied to your message in conversation {call}" : "Egy vendég válaszolt az üzenetére a(z) {call} beszélgetésben",
    "Reminder: You in private conversation {call}" : "Emlékeztető: Ön a(z) {call} magánbeszélgetésben",
    "Reminder: A deleted user in private conversation {call}" : "Emlékeztető: törölt felhasználó a(z) {call} magánbeszélgetésben",
    "Reminder: {user} in private conversation" : "Emlékeztető: {user} egy magánbeszélgetésben",
    "Reminder: You in conversation {call}" : "Emlékeztető: Ön a(z) {call} beszélgetésben",
    "Reminder: {user} in conversation {call}" : "Emlékeztető: {user} a(z) {call} beszélgetésben)",
    "Reminder: A deleted user in conversation {call}" : "Emlékeztető: egy törölt felhasználó a(z) {call} beszélgetésben",
    "Reminder: {guest} (guest) in conversation {call}" : "Emlékeztető: {guest} (vendég) a(z) {call} beszélgetésben",
    "Reminder: A guest in conversation {call}" : "Emlékeztető: egy vendég a(z) {call} beszélgetésben",
    "{user} reacted with {reaction} to your private message" : "{user} ezzel reagált a privát üzenetére: {reaction}",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} ezzel reagált a(z) {call} beszélgetésben lévő üzenetére: {reaction}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Egy törölt felhasználó ezzel reagált a(z) {call} beszélgetésben lévő üzenetére: {reaction}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (vendég) ezzel reagált a(z) {call} beszélgetésben lévő üzenetére: {reaction}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Egy vendég ezzel reagált a(z) {call} beszélgetésben lévő üzenetére: {reaction}",
    "{user} mentioned you in a private conversation" : "{user} megemlítette egy privát beszélgetésben",
    "{user} mentioned group {group} in conversation {call}" : "{user} megemlítette a(z) {group} csoportot a(z) {call} beszélgetésben",
    "{user} mentioned team {team} in conversation {call}" : "{user} megemlítette a(z) {team} csapatot a(z) {call} beszélgetésben",
    "{user} mentioned everyone in conversation {call}" : "{user} megemlített mindenkit a(z) {call} beszélgetésben",
    "{user} mentioned you in conversation {call}" : "{user} megemlítette a(z) {call} beszélgetésben",
    "A deleted user mentioned group {group} in conversation {call}" : "Egy törölt felhasználó megemlítette a(z) {group} csoportot a(z) {call} beszélgetésben",
    "A deleted user mentioned team {team} in conversation {call}" : "Egy törölt felhasználó megemlítette a(z) {team} csapatot a(z) {call} beszélgetésben",
    "A deleted user mentioned everyone in conversation {call}" : "Egy törölt felhasználó megemlített mindenkit a(z) {call} beszélgetésben",
    "A deleted user mentioned you in conversation {call}" : "Egy törölt felhasználó megemlítette a(z) {call} beszélgetésben",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (vendég) megemlítette a(z) {group} csoportot a(z) {call} beszélgetésben",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (vendég) megemlítette a(z) {team} csapatot a(z) {call} beszélgetésben",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (vendég) megemlített mindenkit a(z) {call} beszélgetésben",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (vendég) megemlítette a(z) {call} beszélgetésben",
    "A guest mentioned group {group} in conversation {call}" : "Egy vendég megemlítette a(z) {group} csoportot a(z) {call} beszélgetésben",
    "A guest mentioned team {team} in conversation {call}" : "Egy vendég megemlítette a(z) {team} csapatot a(z) {call} beszélgetésben",
    "A guest mentioned everyone in conversation {call}" : "Egy vendég megemlített mindenkit a(z) {call} beszélgetésben",
    "A guest mentioned you in conversation {call}" : "Egy vendég megemlítette a(z) {call} beszélgetésben",
    "View message" : "Üzenet megtekintése",
    "Dismiss reminder" : "Emlékeztető elvetése",
    "View chat" : "Csevegés megtekintése",
    "{user} invited you to a group conversation: {call}" : "{user} meghívta a következő csoportos beszélgetésbe: {call}",
    "Join call" : "Csatlakozás a híváshoz",
    "Answer call" : "Válasz a hívásra",
    "{user} would like to talk with you" : "{user} szeretne Önnel beszélni",
    "Call back" : "Visszahívás",
    "You missed a call from {user}" : "Nem fogadott hívás tőle: {user}",
    "Accept call" : "Hívás fogadása",
    "Incoming phone call from {call}" : "Bejövő telefonhívás innen: {call}",
    "You missed a phone call from {call}" : "Nem fogadott egy telefonhívást innen: {call}",
    "A group call has started in {call}" : "Csoportos hívás kezdődött itt: {call}",
    "You missed a group call in {call}" : "Nem fogadott csoportos hívás itt: {call}",
    "{email} is requesting the password to access {file}" : "{email} jelszót kér ehhez: {file}",
    "{email} tried to request the password to access {file}" : "{email} megpróbált jelszót kérni ehhez: {file}",
    "Someone is requesting the password to access {file}" : "Valaki jelszót kér ehhez: {file}",
    "Someone tried to request the password to access {file}" : "Valaki megpróbál jelszót kérni ehhez: {file}",
    "Open settings" : "Beállítások megnyitása",
    "Hosted signaling server added" : "Külső jelzőkiszolgáló hozzáadva",
    "The hosted signaling server is now configured and will be used." : "A külső jelzőkiszolgáló beállításra került, és az lesz használva.",
    "Hosted signaling server removed" : "Külső jelzőkiszolgáló eltávolítva",
    "The hosted signaling server was removed and will not be used anymore." : "A külső jelzőkiszolgáló beállításra került, és az lesz használva.",
    "Hosted signaling server changed" : "Külső jelzőkiszolgáló megváltoztatva",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "A külső jelzőkiszolgáló fiókja „{oldstatus}” állapotról erre változott: „{newstatus}”.",
    "pending" : "függőben",
    "active" : "aktív",
    "expired" : "lejárva",
    "blocked" : "blokkolva",
    "error" : "hiba",
    "The certificate of {host} expires in {days} days" : "A(z) {host} tanúsítványa {days} nap múlva lejár",
    "The certificate of {host} expired" : "A(z) {host} tanúsítványa lejárt",
    "Contact via Talk" : "Beszélgetés",
    "Open Talk" : "Beszélgetés megnyitása",
    "Default" : "Alapértelmezett",
    "Presentation" : "Bemutató",
    "Voice room" : "Hangos szoba",
    "Webinar" : "Webinár",
    "Conversations" : "Beszélgetések",
    "Messages in current conversation" : "Üzenetek a jelenlegi beszélgetésben",
    "{user}" : "{user}",
    "Messages" : "Üzenetek",
    "{user} in {conversation}" : "{user} csatlakozott a(z) {conversation} beszélgetéshez",
    "Messages in other conversations" : "Üzenetek más beszélgetésekben",
    "One-to-one rooms always need to show the other users avatar" : "A négyszemközti beszélgetések szobáinak mindig a másik felhasználó profilképét kell megjelenítenie",
    "Invalid emoji character" : "Érvénytelen emodzsi karakter",
    "Invalid background color" : "Érvénytelen háttérszín",
    "Avatar image is not square" : "A profilkép nem négyzetes",
    "Room {number}" : "{number}. szoba",
    "Favorites" : "Kedvencek",
    "Other" : "Egyebek",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "A próbaverzió kérése nem sikerült, mert a próbakiszolgáló nem érhető el. Próbálja újra később.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Probléma van a példány hitelesítésével. Lehet, hogy kívülről nem érhető el az URL az ellenőrzéséhez.",
    "Something unexpected happened." : "Valami váratlan történt.",
    "The URL is invalid." : "Az URL érvénytelen.",
    "An HTTPS URL is required." : "Egy HTTPS URL szükséges.",
    "The email address is invalid." : "Az e-mail-cím érvénytelen.",
    "The language is invalid." : "A nyelv érvénytelen.",
    "The country is invalid." : "Az ország érvénytelen.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Probléma van a próbaverzió kérésével. További információkért ellenőrizze a naplóit.",
    "Too many requests are send from your servers address. Please try again later." : "Probléma van a példány hitelesítésével. Lehet, hogy kívülről nem érhető el az URL ellenőrzéséhez.",
    "There is already a trial registered for this Nextcloud instance." : "Már regisztrált egy próbaverziót ehhez a Nextcloud példányhoz.",
    "Something unexpected happened. Please try again later." : "Valami váratlan történt. Próbálja újra később.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Nem sikerült próbaverziót kérni, mert a próbakiszolgáló helytelenül viselkedett. Próbálja újra később.",
    "Trial requested but failed to get account information. Please check back later." : "Próbaverziót kért, de nem sikerült lekérni a fiókadatait. Nézzen vissza később.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Probléma van a kérés hitelesítésével. Lehet, hogy kívülről nem érhető el az URL az ellenőrzéséhez.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Nem sikerült lekérni a fiókadatokat, mert a próbakiszolgáló helytelenül viselkedett. Nézzen vissza később.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Probléma van a fiókadatok lekérésével. További információkért ellenőrizze a naplóit.",
    "There is no such account registered." : "Nincs ilyen fiók regisztrálva.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Nem sikerült lekérni a fiókadatokat, mert a próbakiszolgáló nem érhető el. Nézzen vissza később.",
    "Deleting the hosted signaling server account failed. Please check back later." : "A külső jelzőkiszolgáló fiókjának törlése nem sikerült. Nézzen vissza később.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Nem sikerült törölni a fiókot, mert a próbakiszolgáló helytelenül viselkedett. Nézzen vissza később.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Probléma van a fiók törlésével. További információkért ellenőrizze a naplóit.",
    "Too many requests are sent from your servers address. Please try again later." : "Túl sok kérés lett küldve a kiszolgáló címéről. Próbálja újra később.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Nem sikerült törölni a fiókot, mert a próbakiszolgáló nem érhető el. Nézzen vissza később.",
    "Note to self" : "Saját jegyzet",
    "A place for your private notes, thoughts and ideas" : "Egy hely a saját jegyzeteknek, gondolatoknak, ötleteknek",
    "Transcript is AI generated and may contain mistakes" : "A leirat MI által lett előállítva, és hibákat tartalmazhat",
    "Summary is AI generated and may contain mistakes" : "Az összefoglaló MI által lett előállítva, és hibákat tartalmazhat",
    "Let's get started!" : "Kezdjünk neki!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "A **Nextcloud Beszélgetés** egy biztonságos, saját kiszolgálású kommunikációs platform, amely zökkenőmentesen épül be a Nextcloud ökoszisztémába.\\An\n\n#### A Nextcloud Beszélgetés kulcsfontosságú funkciói:\n\n* Csevegés privát és csoportos beszélgetésekkel\n* Hang- és videóhívás\n* Fájlmegosztás, és integráció más nextcloudos alkalmazással\n* Testreszabható beszélgetésbeállítások, moderálási és adatvédelmi eszközök\n* Webre, asztali és mobilos (iOS és Android) alkalmazásként\n* Privát és biztonságos kommunikáció\n\n Tudjon meg többet a [felhasználói dokumentációból](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Üdvözöljük a Nextcloud Beszélgetésben\n\nA Nextcloud Beszélgetés egy privát és sokoldalú üzenetküldő alkalmazás, amely beépül a Nextcloudba. Csevegjen privát vagy csoportos beszélgetésekben, működjön együtt hang- és videóhívások használatával, szervezzen webinárokat és eseményeket, szabja testre a beszélgetéseit, és ez csak a kezdte.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Formázza gazdagon a szöveget\n\nA Nextcloud Beszélgetésben használhatja a Markdown szintaxist az üzenetek formázásához. Például, alkalmazzon **félkövér** vagy *dőlt* formázást, esetleg `emelje ki a szöveget kódként`. Akár táblázatokat és címsorokat is hozzáadhat a szövegéhez.\n\nJavítania kell egy elírást, vagy módosítaná a formázást? Szerkessze az üzenetmenü „Üzenet szerkesztése” lehetőségével.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Adjon hozzá mellékleteket és hivatkozásokat\n\nMellékeljen fájlokat a Nextcloud Központból a „+” gomb használatával. Osszon meg elemeket a Fájlokból és más nextcloudos alkalmazásokból. Egyes alkalmazások akár interaktív modulokat is támogatnak, például a Szöveg alkalmazás.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Engedje, hogy folyjon a beszélgetés: említsen meg felhasználók, reagáljon az üzenetekre\n\nMegemlíthet mindenkit a(z) %s használatával, vagy megemlíthet konkrét résztvevőket is, ha kiválasztja a nevüket a listából egy „@” beírása után.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Válaszolhat az üzenetekre, továbbíthatja más csevegésekbe és embereknek, vagy másolhatja az üzenet tartalmát.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Tegyen többet az Okos választóval\n\nEgyszerűen írja be a „/” karaktert, vagy ugorjon a „+” menühöz, hogy megnyissa az Okos választót, amellyel különféle tartalmakat mellékelhet az üzeneteihez. Beállítja az Okos választót, hogy elemeket adjon hozzá nextcloudos alkalmazásokból, GIF-eket, térképhelyeket és MI által előállított tartalmat és egyebeket osszon meg.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Kezelje a beszélgetések beállításait\n\nA beszélgetés menüjében különböző beállításokat talál, mint például:\n* beszélgetés információinak szerkesztése,\n* értesítések kezelése,\n* számos moderációs szabály megadása,\n* hozzáférés és biztonság beállítása,\n* botok engedélyezése,\n* és egyebek.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Egyesült Arab Emírségek",
    "Afghanistan" : "Afganisztán",
    "Antigua and Barbuda" : "Antigua és Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albánia",
    "Armenia" : "Örményország",
    "Angola" : "Angola",
    "Antarctica" : "Antarktisz",
    "Argentina" : "Argentína",
    "American Samoa" : "Amerikai Szamoa",
    "Austria" : "Ausztria",
    "Australia" : "Ausztrália",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland-szigetek",
    "Azerbaijan" : "Azerbajdzsán",
    "Bosnia and Herzegovina" : "Bosznia-Hercegovina",
    "Barbados" : "Barbadosz",
    "Bangladesh" : "Banglades",
    "Belgium" : "Belgium",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint-Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Szultanátus",
    "Bolivia, Plurinational State of" : "Bolívia",
    "Bonaire, Sint Eustatius and Saba" : "Karibi Hollandia",
    "Brazil" : "Brazília",
    "Bahamas" : "Bahamák",
    "Bhutan" : "Bhután",
    "Bouvet Island" : "Bouvet-sziget",
    "Botswana" : "Botswana",
    "Belarus" : "Fehéroroszország",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Kókusz (Keeling)-szigetek",
    "Congo, the Democratic Republic of the" : "Kongói Demokratikus Köztársaság",
    "Central African Republic" : "Közép-afrikai Köztársaság",
    "Congo" : "Kongó",
    "Switzerland" : "Svájc",
    "Côte d'Ivoire" : "Elefántcsontpart",
    "Cook Islands" : "Cook-szigetek",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kína",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Zöld-foki Köztársaság",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Karácsony-szigetek",
    "Cyprus" : "Ciprus",
    "Czechia" : "Csehország",
    "Germany" : "Németország",
    "Djibouti" : "Dzsibuti",
    "Denmark" : "Dánia",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikai Köztársaság",
    "Algeria" : "Algéria",
    "Ecuador" : "Ecuador",
    "Estonia" : "Észtország",
    "Egypt" : "Egyiptom",
    "Western Sahara" : "Nyugat-Szahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanyolország",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finnország",
    "Fiji" : "Fidzsi-szigetek",
    "Falkland Islands (Malvinas)" : "Falkland-szigetek",
    "Micronesia, Federated States of" : "Mikronézia",
    "Faroe Islands" : "Feröer-szigetek",
    "France" : "Franciaország",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Egyesült Királyság",
    "Grenada" : "Grenada",
    "Georgia" : "Grúzia",
    "French Guiana" : "Francia Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghána",
    "Gibraltar" : "Gibraltár",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Egyenlítői-Guinea",
    "Greece" : "Görög",
    "South Georgia and the South Sandwich Islands" : "Dél-Georgia és a Dél-Sandwich-szigetek",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard-sziget és McDonald-szigetek",
    "Honduras" : "Honduras",
    "Croatia" : "Horvátország",
    "Haiti" : "Haiti",
    "Hungary" : "Magyarország",
    "Indonesia" : "Indonézia",
    "Ireland" : "Írország",
    "Israel" : "Izrael",
    "Isle of Man" : "Man-sziget",
    "India" : "India",
    "British Indian Ocean Territory" : "Brit tengerentúli területek",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Irán",
    "Iceland" : "Izland",
    "Italy" : "Olaszország",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordánia",
    "Japan" : "Japán",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizisztán",
    "Cambodia" : "Kambodzsa",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comore",
    "Saint Kitts and Nevis" : "Saint Kitts és Nevis",
    "Korea, Democratic People's Republic of" : "Észak-Korea",
    "Korea, Republic of" : "Dél-Korea",
    "Kuwait" : "Kuvait",
    "Cayman Islands" : "Kajmán-szigetek",
    "Kazakhstan" : "Kazahsztán",
    "Lao People's Democratic Republic" : "Laoszi Népi Demokratikus Köztársaság",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Srí Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litvánia",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettország",
    "Libya" : "Líbia",
    "Morocco" : "Marokkó",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldovai Köztársaság",
    "Montenegro" : "Montenegró",
    "Saint Martin (French part)" : "Szent Márton-sziget (Francia rész)",
    "Madagascar" : "Madagaszkár",
    "Marshall Islands" : "Marshall-szigetek",
    "North Macedonia" : "Észak-Macedónia",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongólia",
    "Macao" : "Makaó",
    "Northern Mariana Islands" : "Északi-Mariana-szigetek",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauritánia",
    "Montserrat" : "Montserrat",
    "Malta" : "Málta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldív-szigetek",
    "Malawi" : "Malawi",
    "Mexico" : "Mexikó",
    "Malaysia" : "Malajzia",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Új-Kaledónia",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk-sziget",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Hollnadia",
    "Norway" : "Norvégia",
    "Nepal" : "Nepál",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Új-Zéland",
    "Oman" : "Omán",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Francia Polinézia",
    "Papua New Guinea" : "Pápua Új-Guinea",
    "Philippines" : "Fülöp-szigetek",
    "Pakistan" : "Pakisztán",
    "Poland" : "Lengyelország",
    "Saint Pierre and Miquelon" : "Saint-Pierre és Miquelon",
    "Pitcairn" : "Pitcairn-szigetek",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palesztína",
    "Portugal" : "Portugália",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Románia",
    "Serbia" : "Szerbia",
    "Russian Federation" : "Oroszország",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Szaúd-Arábia",
    "Solomon Islands" : "Salamon-szigetek",
    "Seychelles" : "Seychelle-szigetek",
    "Sudan" : "Szudán",
    "Sweden" : "Svédország",
    "Singapore" : "Szingapúr",
    "Saint Helena, Ascension and Tristan da Cunha" : "Szent Ilona, Ascension és Tristan da Cunha",
    "Slovenia" : "Szlovénia",
    "Svalbard and Jan Mayen" : "Svalbard és Jan Mayen",
    "Slovakia" : "Szlovákia",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Szenegál",
    "Somalia" : "Szomália",
    "Suriname" : "Suriname",
    "South Sudan" : "Dél-Szudán",
    "Sao Tome and Principe" : "São Tomé és Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Szent Márton-sziget (Holland rész)",
    "Syrian Arab Republic" : "Szíriai Arab Köztársaság",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks- és Caicos-szigetek",
    "Chad" : "Csád",
    "French Southern Territories" : "Francia déli területek",
    "Togo" : "Togo",
    "Thailand" : "Thaiföld",
    "Tajikistan" : "Tádzsikisztán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Kelet-Timor",
    "Turkmenistan" : "Türkmenisztán",
    "Tunisia" : "Tunézia",
    "Tonga" : "Tonga",
    "Turkey" : "Törökország",
    "Trinidad and Tobago" : "Trinidad és Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Tajvan",
    "Tanzania, United Republic of" : "Tanzánia",
    "Ukraine" : "Ukrajna",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Amerikai Egyesült Államok lakatlan külbirtokai",
    "United States of America" : "Amerikai Egyesült Államok",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Üzbegisztán",
    "Holy See" : "Apostoli Szentszék",
    "Saint Vincent and the Grenadines" : "Saint Vincent és a Grenadine-szigetek",
    "Venezuela, Bolivarian Republic of" : "Venezuela",
    "Virgin Islands, British" : "Brit Virgin-szigetek",
    "Virgin Islands, U.S." : "Amerikai Virgin-szigetek",
    "Viet Nam" : "Vietnám",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis és Futuna",
    "Samoa" : "Szamoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Dél-afrikai Köztársaság",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Háttér elhomályosítása",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Nem sikült a WASM fájlok betöltési támogatásának ellenőrzése. Ellenőrizze kézileg, hogy a webkiszolgálója kiszolgálja a `.wasm` fájlokat.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "A webkiszolgálója nincs helyesen beállítva a `.wasm` fájlok kiszolgálására. Ez általában az Nginx konfiguráció hibája. A háttér elhomályosításához szükség van a `.wasm` kiszolgálására. Hasonlítsa össze a Nginx konfigurációját a dokumentációban javasolttal.",
    "Talk configuration values" : "A Beszélgetés konfigurációs értékei",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "A maximális híváshossz kényszerítése csak rendszerszintű cron esetén támogatott. Engedélyezze a rendszerszintű cront, vagy távolítsa el a `max_call_duration` konfigurációt.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "A kicsi `max_call_duration` értékek (jelenleg ennyi: %d) a műszaki korlátok miatt nem tarthatóak be. A háttérfeladat csak 5 percenként fut, így saját felelősségre használja.",
    "Federation" : "Föderáció",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Erősen ajánlott a „memcache.locking” használata, ha a Beszélgetésben engedélyezve van a föderáció.",
    "High-performance backend" : "Nagy teljesítményű háttérrendszer",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Nincs Nagy teljesítményű háttérrendszer beállítva – A Nextcloud Talk enélkül történő futtatása csak nagyon kis hívások (legfeljebb 2-3 résztvevő) esetén skálázódik. Állítson be egy nagy teljesítményű háttérrendszert, hogy a több résztvevős hívások is zökkenőmentesek legyenek.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "A Nagy teljesítményű háttérrendszer „conversation_cluster” módban történő futtatása elavult, és nem lesz támogatva a következő verzióban. A nagy teljesítményű háttérrendszer ma már támogatja a valódi klaszterezést, így azt kell helyette használni.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "A több Nagy teljesítményű háttérrendszer megadása elavult, és nem lesz támogatva a következő verzióban. Helyette egy terheléselosztót kell telepíteni klaszterezett jelzőkiszolgálókkal, majd be kell állítani a Beszélgetés beállításaiban.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "A(z) %1$s algoritmushoz használt nyilvános kulcs nem felel meg a tárolt privát kulcsnak. A probléma megoldásához futtassa ezt: %2$s.",
    "High-performance backend not configured correctly. Run %s for details." : "A Nagy teljesítményű háttérrendszer nincs helyesen beállítva. A részletekért futtassa ezt: %s.",
    "High-performance backend not configured correctly" : "A Nagy teljesítményű háttérrendszer nincs helyesen beállítva",
    "Error: Cannot connect to server" : "Hiba: Nem lehet csatlakozni a kiszolgálóhoz",
    "Error: Server did not respond with proper JSON" : "Hiba: A kiszolgáló nem megfelelő JSON üzenettel válaszolt",
    "Error: Certificate expired" : "Hiba: Lejárt tanúsítvány",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Hiba: A Nextcloud kiszolgáló és a Nagy teljesítményű háttérrendszer rendszerideje nincs szinkronban. Győződjön meg arról, hogy mindkét kiszolgáló ugyanahhoz az időkiszolgálóhoz kapcsolódik, vagy szinkronizálja őket kézileg.",
    "Could not get version" : "Nem lehet lekérni a verziót",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Hiba: Futó verzió: {version}; A kiszolgálót frissíteni kell, hogy kompatibilis legyen a Beszélgetés ezen verziójával",
    "Error: Server responded with: {error}" : "Hiba: A kiszolgáló válasza: {error}",
    "Error: Unknown error occurred" : "Hiba: Ismeretlen hiba történt",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Figyelmeztetés: futó verzió: {version}; a kiszolgáló nem támogatja a jelenlegi Beszélgetés verzió összes funkcióját, hiányzó funkciók: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Erősen ajánlott, hogy állítson be egy memória-gyorsítótárat, ha a Nextcloud Beszélgetést egy Nagy teljesítményű háttérrendszerrel futtatja.",
    "Client Push" : "Kliensleküldés",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "A Kliensleküldés telepítve van, ez növeli a Beszélgetés értesítéseinek pontosságát.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "A {notify_push} nincs telepítve. Ez késleltetett Beszélgetés értesítésekhez vezethet.",
    "Recording backend" : "Felvételi háttérrendszer",
    "Using the recording backend requires a High-performance backend." : "A felvételi háttérrendszerhez szükség van a Nagy teljesítményű háttérrendszerre.",
    "No recording backend configured" : "Nincs felvételi háttérrendszer beállítva",
    "SIP configuration" : "SIP beállítások",
    "Using the SIP functionality requires a High-performance backend." : "A SIP funkcionalitáshoz szükség van a Nagy teljesítményű háttérrendszerre.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "A hozzárendelt Beszélgetés telefonszámok nem kezdődhetnek +-szal vagy 0-val. Távolítsa el vagy frissítse a következő számokat:\n{list}",
    "No SIP backend configured" : "Nincs SIP háttérrendszer beállítva",
    "Invalid date, date format must be YYYY-MM-DD" : "Érvénytelen dátum, a dátumnak YYYY-MM-DD formátumúnak kell lennie",
    "Conversation not found" : "Beszélgetés nem található",
    "Path is already shared with this conversation" : "Az útvonal már meg van osztva ezzel a beszélgetéssel",
    "Chat, video & audio-conferencing using WebRTC" : "Csevegés, video- és hangkonferencia WebRTC használatával",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Csevegés, video- és hangkonferencia WebRTC használatával\n\n* 💬 **Csevegés** A Nextcloud Beszélgetés egyszerű szöveges csevegést tartalmaz, amellyel fájlokat oszthat meg vagy tölthet fel a Nextcloud Fájlok alkalmazásba vagy a helyi eszközére, és megemlíthet más résztvevőket.\n* 👥 **Privát, csoportos, nyilvános és jelszóval védett hívások!** Hívjon meg valakit, egy teljes csoportot vagy küldjön egy nyilvános hivatkozást a hívásba való meghíváshoz.\n* 🌐 **Föderált csevegések** Csevegjen más Nextcloud-felhasználókkal a saját kiszolgálóikon\n* 💻 **Képernyőmegosztás!** Ossza meg képernyőjét a hívása résztvevőivel.\n* 🚀 **Integráció más Nextcloud alkalmazásokkal**, mint a Fájlok, Naptár, Felhasználói állapot, Irányítópult, Folyamat, Térképek, Okos választó, Névjegyek, Kártyák és még sok más.\n* 🌉 **Szinkronizáljon más csevegőmegoldásokkal** Azáltal, hogy a [Matterbridge](https://github.com/42wim/matterbridge/) integrálva lett a Beszélgetéssel, számos más csevegőmegoldást integrálhat a Nextcloud Beszélgetésbe, és fordítva.",
    "Leave call" : "Hívás elhagyása",
    "Navigating away from the page will leave the call in {conversation}" : "Az oldalról való elnavigálással elhagyja a hívást itt: {conversation}",
    "Stay in call" : "Hívásban maradás",
    "Error occurred when getting the conversation information" : "Hiba történt a beszélgetés információinak lekérése során",
    "Duplicate session" : "Ismétlődő munkamenet",
    "Discuss this file" : "Fájl megbeszélése",
    "Loading …" : "Betöltés…",
    "Share this file with others to discuss it" : "Fájl megosztása másokkal, hogy beszélgethessenek róla",
    "Join conversation" : "Csatlakozás a beszélgetéshez",
    "Share this file" : "Fájl megosztása",
    "Error occurred when joining the conversation" : "Hiba történt a beszélgetéshez csatlakozás során",
    "This conversation is password-protected." : "Ez a beszélgetés jelszóval védett.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Többszöri sikertelen bejelentkezési kísérletet észleltünk az IP-címéről. A legközelebbi kísérlete így 30 másodperccel késleltetve lesz.",
    "The password is wrong. Try again." : "Hibás jelszó. Próbálja újra.",
    "Password" : "Jelszó",
    "Submit" : "Beküldés",
    "Error requesting the password." : "Hiba a jelszó kérésekor.",
    "Request password" : "Jelszó kérése",
    "This conversation has ended" : "Ez a beszélgetés véget ért",
    "Close Talk sidebar" : "Beszélgetés oldalsáv bezárása",
    "Open Talk sidebar" : "Beszélgetés oldalsáv megnyitása",
    "Everyone" : "Mindenki",
    "Users and moderators" : "Felhasználók és moderátorok",
    "Moderators only" : "Csak moderátorok",
    "Disable calls" : "Hívások letiltása",
    "Save changes" : "Változások mentése",
    "Saving …" : "Mentés…",
    "Saved!" : "Elmentve!",
    "Limit to groups" : "Csoportokra korlátozás",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ha legalább egy csoport ki van választva, akkor csak a felsorolt csoportok lehetnek részesei a beszélgetésnek.",
    "Guests can still join public conversations." : "A vendégek továbbra is csatlakozhatnak a nyilvános beszélgetésekhez.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Azok a felhasználók, akik már nem tudják tovább használni a Beszélgetést, továbbra is résztvevőként lesznek felsorolva a korábbi beszélgetéseikben, és a csevegőüzeneteik is meg lesznek tartva.",
    "Limit using Talk" : "Beszélgetés használatának korlátozása",
    "Limit creating a public and group conversation" : "Nyilvános és csoportos beszélgetés létrehozásának korlátozása",
    "Limit creating conversations" : "Beszélgetés létrehozásának korlátozása",
    "Limit starting a call" : "Hívásindítás korlátozása",
    "Limit starting calls" : "Hívások indításának korlátozása",
    "When a call has started, everyone with access to the conversation can join the call." : "Ha egy hívás elkezdődött, akkor mindenki csatlakozhat a híváshoz, aki hozzáfér a beszélgetéshez.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "A következő botok vannak telepítve erre a kiszolgálóra. A dokumentációban megtalálja annak a részleteit, hogy {linkstart1}miként készítse el a saját botját{linkend} vagy {linkstart2}botjait{linkend}, és hogyan engedélyezze őket a kiszolgálón.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Nincsenek botok telepítve erre a kiszolgálóra. A dokumentációban megtalálja annak a részleteit, hogy {linkstart1}miként készítse el a saját botját{linkend} vagy {linkstart2}botjait{linkend}, és hogyan engedélyezze őket a kiszolgálón.",
    "Description is not provided" : "Nincs leírás",
    "Locked for moderators" : "Zárolva a moderátorok részére",
    "Enabled" : "Engedélyezve",
    "Disabled" : "Letiltva",
    "Bots settings" : "Botok beállításai",
    "State" : "Állapot",
    "Name" : "Név",
    "Last error" : "Utolsó hiba",
    "Total errors count" : "Összes hiba",
    "Find more bots" : "További botok keresése",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "A megbízható kiszolgálók a {linkstart}Megosztási beállítások oldalon{linkend} állíthatóak be.",
    "Beta" : "Béta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "A föderált csevegések és hívások már működnek. A mellékletkezelés egy jövőbeli verzióban érkezik.",
    "Enable Federation in Talk app" : "Föderáció engedélyezése a Beszélgetés alkalmazásban",
    "Permissions" : "Jogosultságok",
    "Allow users to be invited to federated conversations" : "Engedélyezés, hogy a felhasználókat föderált beszélgetésekbe hívják meg",
    "Allow users to invite federated users into conversation" : "Engedélyezés, hogy a felhasználók föderált felhasználókat hívjanak meg",
    "Only allow to federate with trusted servers" : "A föderáció csak megbízható kiszolgálókkal való engedélyezése",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Ha legalább egy csoport ki van választva, akkor csak a felsorolt csoportok tagjai hívhatnak meg föderált felhasználókat a beszélgetésekbe.",
    "Groups allowed to invite federated users" : "Föderált felhasználókat meghívható csoportok",
    "Select groups …" : "Csoportok kiválasztása…",
    "All messages" : "Összes üzenet",
    "@-mentions only" : "Csak a @-említések",
    "Off" : "Ki",
    "General settings" : "Általános beállítások",
    "Default notification settings" : "Alapértelmezett értesítési beállítások",
    "Default group notification" : "Alapértelmezett csoportértesítés",
    "Default group notification for new groups" : "Alapértelmezett csoportértesítés az új csoportok számára",
    "Integration into other apps" : "Integráció más alkalmazásokba",
    "Allow conversations on files" : "Beszélgetések engedélyezése a fájlokon",
    "Allow conversations on public shares for files" : "Beszélgetések engedélyezése a fájlokon a nyilvános megosztásokban",
    "End-to-end encrypted calls" : "Végpontok közti titkosítással rendelkező hívások",
    "Enable encryption" : "Titkosítás engedélyezése",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "A beállított SIP-híddal és végpontok közti titkosítással rendelkező hívásokhoz a Nagy teljesítményű háttérrendszer és a SIP-híd új verziója szükséges.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "A mobilkliensek pillanatnyilag nem támogatják a végpontok közti titkosítással rendelkező hívásokat.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "A fenti gombra kattintva az űrlapon szereplő információk el lesznek küldve a Struktur AG kiszolgálóinak. További információt a {linkstart}spreed.eu{linkend} oldalon talál.",
    "Pending" : "Függőben",
    "Error" : "Hiba",
    "Blocked" : "Blokkolva",
    "Active" : "Aktív",
    "Expired" : "Elévült",
    "Never" : "Soha",
    "The trial could not be requested. Please try again later." : "Nem lehetett próbaverziót kérni. Próbája újra később.",
    "The account could not be deleted. Please try again later." : "A fiókot nem sikerült törölni. Próbája újra később.",
    "Hosted High-performance backend" : "Külső kiszolgálású Nagy teljesítményű háttérrendszer",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Partnerünk, a Struktur AG szolgáltatásként nyújt jelzőkiszolgálót. Ehhez csak ki kell töltenie az alábbi űrlapot, és a Nextcloud kérni fogja. Miután beállította az Ön számára a kiszolgálót, a hitelesítő adatok automatikusan kitöltésre kerülnek. Ez felülírja a meglévő jelzőkiszolgáló beállításait.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Ha a Nagy teljesítményű háttérrendszer fiókja STUN vagy TURN funkcionalitást tartalmaz, akkor a beállítások aszerint fognak frissülni.",
    "URL of this Nextcloud instance" : "Ezen Nextcloud-példány webcíme",
    "Full name of the user requesting the trial" : "A próbát kérő felhasználó teljes neve",
    "Email of the user" : "A felhasználó e-mail-címe",
    "Language" : "Nyelv",
    "Country" : "Ország",
    "Request signaling server trial" : "Jelzőkiszolgáló próbájának kérése",
    "You can see the current status of your hosted signaling server in the following table." : "A következő táblázatban láthatja a külső üzemeltetésű jelzőkiszolgáló jelenlegi állapotát.",
    "Status" : "Állapot",
    "Created at" : "Létrehozás ideje:",
    "Expires at" : "Elévülés ideje:",
    "Limits" : "Korlátok",
    "STUN included" : "STUN-t tartalmaz",
    "Yes" : "Igen",
    "No" : "Nem",
    "TURN included" : "TURN-t tartalmaz",
    "Delete the signaling server account" : "A jelzőkiszolgáló-fiók törlése",
    "_%n user_::_%n users_" : ["%n felhasználó","%n felhasználó"],
    "Installed version: {version}" : "Telepített verzió: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Telepítheti a Matterbridge-dzet, hogy összekapcsolja a Nextcloud Beszélgetés alkalmazást néhány további szolgáltatással. További részletekért keresse fel a {linkstart1}GitHub oldalukat{linkend}. Az alkalmazás letöltése és telepítése eltarthat egy ideig. Időtúllépés esetén telepítse kézzel az {linkstart2}alkalmazástárból{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "A Matterbridge binárisa hibás jogosultságokkal rendelkezik. Győződjön meg arról, hogy a Matterbridge bináris fájljának helyes a tulajdonosa, és végrehajtható. Itt található: „/…/nextcloud/apps/talk_matterbridge/bin/”.",
    "Matterbridge binary was not found or couldn't be executed." : "A Matterbridge binárisa nem található, vagy nem futtatható.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "A konfiguráción keresztül kézileg is beállíthatja a Matterbridge binárisának elérési útját. További információt a {linkstart}Matterbridge integrációs dokumentációjában{linkend} talál.",
    "Downloading …" : "Letöltés…",
    "Install Talk Matterbridge" : "Beszélgetés Matterbridge telepítése",
    "An error occurred while installing the Matterbridge app" : "Hiba történt a Matterbridge alkalmazás telepítésekor",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Hiba történt a Beszélgetés Matterbridge telepítése során. Telepítse kézileg.",
    "Failed to execute Matterbridge binary." : "A Matterbridge binárisának végrehajtása sikertelen.",
    "Matterbridge integration" : "Matterbridge integráció",
    "Enable Matterbridge integration" : "Matterbridge integráció engedélyezése",
    "Status: Checking connection" : "Állapot: kapcsolat ellenőrzése",
    "OK: Running version: {version}" : "OK: Futtatott verzió: {version}",
    "Error: Server seems to be a Signaling server" : "Hiba: A kiszolgáló jelzőkiszolgálónak tűnik",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Hiba: A Nextcloud-kiszolgáló és a felvételi háttérrendszer kiszolgálóján eltérő a rendszeridő. Győződjön meg arról, hogy mindkét kiszolgáló ugyanahhoz az időkiszolgálóhoz kapcsolódik, vagy szinkronizálja kézileg az időket.",
    "Recording backend URL" : "Felvételi háttérrendszer webcíme",
    "Validate SSL certificate" : "SSL tanúsítvány érvényesítése",
    "Delete this server" : "Ezen kiszolgáló törlése",
    "Test this server" : "Kiszolgáló tesztelése",
    "Disabled for all calls" : "Minden hivásban letiltva",
    "Enabled for all calls" : "Minden hívásban engedélyezve",
    "Configurable on conversation level by moderators" : "A moderátorok beszélgetési szinten konfigurálhatók",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Az „upload_max_filesize” vagy a „post_max_size” PHP-beállítás legfeljebb {maxUpload} sebességű fájlfeltöltést tesz lehetővé.",
    "Recording backend settings saved" : "A felvételi háttérrendszer beállításai mentve",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "A moderátorok a beszélgetés szintjén engedélyezhetik a hozzájárulást. A rögzítéshez az összes résztvevő beleegyezése szükséges, még mielőtt csatlakoznának bármelyik híváshoz ebben a beszélgetésben.",
    "The consent to be recorded will be required for each participant before joining every call." : "A rögzítéshez az összes résztvevő beleegyezése szükséges, még mielőtt egy híváshoz csatlakoznának.",
    "The consent to be recorded is not required." : "Nem szükséges hozzájárulás a felvételhez.",
    "Recording backend configuration is only possible with a High-performance backend." : "A felvételi háttérrendszer beállítása csak Nagy teljesítményű háttérrendszer esetén lehetséges.",
    "Add a new recording backend server" : "Új felvételi háttérrendszer hozzáadása",
    "Shared secret" : "Megosztott titok",
    "Recording consent" : "Felvételi hozzájárulás",
    "Recording transcription" : "Felvétel leiratozása",
    "Automatically transcribe call recordings with a transcription provider" : "Hívásfelvételek automatikus leiratozása egy szolgáltató segítségével",
    "Automatically summarize call recordings with transcription and summary providers" : "Hívásfelvételek automatikus összefoglalása leiratozási és összefoglalási szolgáltatókkal",
    "SIP configuration saved!" : "SIP konfiguráció mentve.",
    "SIP configuration is only possible with a High-performance backend." : "A SIP konfiguráció csak Nagy teljesítményű háttérrendszer mellett lehetséges.",
    "Enable SIP Dial-out option" : "SIP kitárcsázási lehetőség engedélyezése",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "A jelzőkiszolgáló frissítése szükséges a SIP kitárcsázási funkció támogatásához.",
    "Do not show SIP Dial-out caller number" : "Ne jelenítse meg a SIP kitárcsázási számot",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "A névtelen tag megjelenítése mint „ismeretlen” vagy „visszatartott szám”",
    "Dial-out number" : "Kitárcsázási szám",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "E164 formátumú szám, mely tartalék hívószámként szolgál a kimenő hívásokhoz",
    "Dial-out prefix" : "Kitárcsázási előhívó",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "A kimenő hívásokhoz használt felhasználói szám (alapértelmezés: `+`)",
    "Restrict SIP configuration" : "A SIP beállítások korlátozása",
    "Enable SIP configuration" : "SIP beállítások engedélyezése",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Csak az alábbi csoportok felhasználói engedélyezhetik a SIP-et az általuk moderált beszélgetésekben",
    "Phone number (Country)" : "Telefonszám (ország)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Ez az információt meghívó e-mailben lesz elküldve, és az oldalsávon jelenik meg az összes résztvevő számára.",
    "Nextcloud base URL" : "Nextcloud alapwebcím",
    "Talk Backend URL" : "Beszélgetés háttérrendszer-webcím",
    "WebSocket URL" : "WebSocket webcím",
    "Available features" : "Elérhető funkciók",
    "Error: Websocket connection failed" : "Hiba: Nem sikerült a WebSocket kapcsolat",
    "Error code" : "Hibakód",
    "Error message" : "Hibaüzenet",
    "Error: Websocket connection failed. Check browser console" : "Hiba: Nem sikerült a WebSocket kapcsolat. Ellenőrizze a böngészőkonzolt.",
    "High-performance backend URL" : "Nagy teljesítményű háttérrendszer webcíme",
    "Missing High-performance backend warning hidden" : "A hiányzó Nagy teljesítményű háttérrendszer figyelmeztetése elrejtve",
    "High-performance backend settings saved" : "A Nagy teljesítményű háttérrendszer beállításai mentve",
    "Nextcloud Talk setup not complete" : "A Nextcloud Beszélgetés beállítása nincs kész",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Vegye figyelembe, hogy a 2 résztvevősnél nagyobb hívásoknál, a Nagy teljesítményű háttérrendszer nélkül, a résztvevők kapcsolódási problémákat, és magas terhelést tapasztalhatnak az eszközükön.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Telepítse a Nagy teljesítményű háttérrendszert, hogy biztosítsa a több résztvevős hívások zökkenőmentes működését.",
    "Nextcloud portal" : "Nextcloud portál",
    "Quick installation guide" : "Gyors telepítési útmutató",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "A Nagy teljesítményű háttérrendszer szükséges a több résztvevős hívásokhoz és beszélgetésekhez. A háttérrendszer nélkül az összes résztvevőnek egyesével kell feltölteni a videót az összes többi résztvevőnek, ami nagy valószínűséggel kapcsolódási problémákat és magas terhelést okoz a résztvevő eszközökön.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Erősen ajánlott elosztott gyorsítótárat beállítani, ha a Nextcloud Beszélgetést a Nagy teljesítményű háttérrendszerrel használja.",
    "Add High-performance backend server" : "Nagy teljesítményű háttérrendszer hozzáadása",
    "Warn about connectivity issues in calls with more than 2 participants" : "Figyelmeztetés a kapcsolódási problémákra, ha a hívások 2-nél több résztvevőt tartalmaznak",
    "STUN server URL" : "STUN-kiszolgáló webcíme",
    "The server address is invalid" : "A kiszolgálócím érvénytelen",
    "STUN settings saved" : "STUN beállítások mentve",
    "STUN servers" : "STUN kiszolgálók",
    "A STUN server is used to determine the public IP address of participants behind a router." : "A STUN kiszolgáló a router mögötti résztvevők nyilvános IP-címének megállapítására szolgál.",
    "Add a new STUN server" : "Új STUN-kiszolgáló hozzáadása",
    "{schema} scheme must be used with a domain" : "A(z) {schema} sémát egy domainen kell használni",
    "{option1} and {option2}" : "{option1} és {option2}",
    "{option} only" : "csak {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: A TURN-kiszolgáló visszatért a sikeres ICE-jelöltekkel",
    "Error: No working ICE candidates returned by the TURN server" : "Hiba: A TURN-kiszolgáló nem adott vissza egyetlen működő ICE-jelöltet sem",
    "Testing whether the TURN server returns ICE candidates" : "Tesztelés, hogy a TURN-kiszolgáló visszatér-e az ICE-jelöltekkel",
    "TURN server schemes" : "TURN-kiszolgáló sémái",
    "TURN server URL" : "TURN-kiszolgáló webcíme",
    "TURN server secret" : "TURN-kiszolgáló titka",
    "TURN server protocols" : "TURN-kiszolgáló protokolljai",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "A TURN kiszolgáló a tűzfal mögött lévő résztvevők forgalmának proxyzására szolgál. Ha az egyes résztvevők nem tudnak csatlakozni másokhoz, akkor valószínűleg TURN kiszolgálóra van szükség. A telepítési utasításokért lásd {linkstart}ezt a dokumentációt{linkend}.",
    "TURN settings saved" : "TURN beállítások mentve",
    "TURN servers" : "TURN-kiszolgálók",
    "Add a new TURN server" : "Új TURN-kiszolgáló hozzáadása",
    "Failed" : "Sikertelen",
    "OK" : "Rendben",
    "Checking …" : "Ellenőrzés…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Sikertelen: a WebAssembly le van tiltva, vagy nem támogatott ebben a böngészőben. Engedélyezze a WebAssemblyt, vagy az ellenőrzéshez használjon egy olyan böngészőt, amely támogatja.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Sikertelen: a webkiszolgáló nem helyesen adta vissza a „.wasm” és a „.tflite” fájlokat. Ellenőrizze a Beszélgetés dokumentációjának „Rendszerkövetelmények” szakaszát.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Rendben: a webkiszolgáló helyesen adta vissza a „.wasm” és a „.tflite” fájlokat.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Úgy tűnik, hogy a PHP és Apache konfiguráció nem teljes. Vegye figyelembe, hogy a PHP csak a MPM_PREFORK modullal, a PHP-FPM pedig csak az MPM_EVENT modullal használható.",
    "Web server setup checks" : "Webkiszolgáló beállítási ellenőrzések",
    "Files required for virtual background can be loaded" : "A virtuális háttérhez szükséges fájlok betölthetők",
    "Federated user" : "Föderált felhasználó",
    "Assign participants to rooms" : "A résztvevők hozzárendelése a szobákhoz",
    "Configure breakout rooms" : "Szétbontott szobák beállítása",
    "Number of breakout rooms" : "Szétbontott szobák száma",
    "You can create from 1 to 20 breakout rooms." : "1 és 20 közti szétbontott szobát hozhat létre.",
    "Assignment method" : "Hozzárendelési mód",
    "Automatically assign participants" : "Résztvevők automatikus hozzárendelése",
    "Manually assign participants" : "Résztvevők kézi hozzárendelése",
    "Allow participants to choose" : "Engedélyezés, hogy a résztvevők választhassanak",
    "Create rooms" : "Szobák létrehozása",
    "Confirm" : "Megerősítés",
    "Create breakout rooms" : "Szétbontott szobák létrehozása",
    "Reset" : "Alaphelyzetbe állítás",
    "Delete breakout rooms" : "Szétbontott szobák törlése",
    "Room {roomNumber}" : "{numberNumber}. szoba",
    "Current breakout rooms and settings will be lost" : "A jelenlegi szétbontott szobák és beállítások elvesznek",
    "Cancel" : "Mégse",
    "Unassigned participants" : "Nem hozzárendelt résztvevő",
    "Back" : "Vissza",
    "Assign" : "Hozzárendelés",
    "Add participant \"{user}\"" : "„{user}” résztvevő hozzáadása",
    "Now" : "Most",
    "Invalid calendar selected" : "Érvénytelen naptár kiválasztva",
    "Invalid start time selected" : "Érvénytelen kezdőidőpont kiválasztva",
    "Invalid end time selected" : "Érvénytelen záróidőpont kiválasztva",
    "Unknown error occurred" : "Ismeretlen hiba történt",
    "Sending no invitations" : "Nem lesz meghívó kiküldve",
    "{participant0} will receive an invitation" : "{participant0} meghívót fog kapni",
    "{participant0} and {participant1} will receive invitations" : "{participant0} és {participant1} meghívót fog kapni",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} és még %n személy meghívót fog kapni","{participant0}, {participant1} és még %n személy meghívót fog kapni"],
    "Invite {user}" : "{user} meghívása",
    "Invite all users and emails in this conversation" : "Összes felhasználó és e-mail-cí meghívása ebbe a beszélgetésbe",
    "Meeting created" : "Találkozó létrehozva",
    "Upcoming meetings" : "Következő találkozók",
    "No upcoming meetings" : "Nincs következő találkozó",
    "Schedule a meeting" : "Találkozó ütemezése",
    "Meeting title" : "Találkozó címe",
    "From" : "Feladó",
    "To" : "Címzett",
    "Calendar" : "Naptár",
    "Attendees" : "Résztvevők",
    "No other participants to send invitations to." : "Nincs más résztvevő, akinek meghívót kellene küldeni.",
    "Add attendees" : "Résztvevők hozzáadása",
    "Save" : "Mentés",
    "Search participants" : "Résztvevők keresése",
    "No results" : "Nincs találat",
    "Done" : "Kész",
    "Disable live transcription" : "Élő leiratozás kikapcsolása",
    "Enable live transcription (generated by AI)" : "Élő leiratozás bekapcsolása (MI által előállítva)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Élő leiratozás bekapcsolása (Az Élő leiratozás alkalmazás nincs telepítve)",
    "Disable live translation" : "Élő fordítás bekapcsolása",
    "Enable live translation (generated by AI)" : "Élő fordítás bekapcsolása (MI által előállítva)",
    "Original language" : "Eredeti nyelv",
    "Live translations app is not installed" : "Az Élő fordítás alkalmazás nincs telepítve",
    "Original language: {languageName}" : "Eredeti nyelv: {languageName}",
    "Translated language" : "Fordítás nyelve",
    "Translated language: {languageName}" : "Fordítás nyelve: {languageName}",
    "Exit full screen (F)" : "Kilépés a teljes képernyős módból (F)",
    "Full screen (F)" : "Teljes képernyő (F)",
    "Speaker view" : "Beszélő nézet",
    "Grid view" : "Rács nézet",
    "Error when trying to load the available live transcription languages" : "Hiba történt az elérhető élő leiratozási nyelvek betöltése során",
    "Failed to enable live transcription" : "Nem sikerült az élő leiratozás bekapcsolása",
    "Failed to enable live translations" : "Nem sikerült az élő fordítás bekapcsolása",
    "Failed to disable live translations" : "Nem sikerült az élő fordítás kikapcsolása",
    "Recording consent is required" : "Felvételi hozzájárulás szükséges",
    "This conversation is read-only" : "Ez a beszélgetés csak olvasható",
    "Conversation not found or not joined" : "A beszélgetés nem található, vagy nem csatlakozott",
    "Lobby is still active and you're not a moderator" : "A váró még mindig aktív, és Ön nem moderátor",
    "Connection failed" : "Nem sikerült a kapcsolat",
    "Reload" : "Újratöltés",
    "{nickName} raised their hand." : "{nickName} felemelte a kezét.",
    "A participant raised their hand." : "Egy résztvevő felemelte a kezét.",
    "Collapse stripe" : "Csík összecsukása",
    "Expand stripe" : "Csík kibontása",
    "Previous page of videos" : "A videók előző oldala",
    "Next page of videos" : "A videók következő oldala",
    "Connecting …" : "Csatlakozás…",
    "Calling …" : "Hívás…",
    "Waiting for {user} to join the call" : "Várakozás, hogy {user} csatlakozzon a híváshoz",
    "Waiting for others to join the call …" : "Várakozás, hogy mások is csatlakozzanak a híváshoz…",
    "You can invite others in the participant tab of the sidebar" : "Másokat az oldalsávon található „résztvevők” fülön tud meghívni",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Másokat az oldalsávon található „résztvevők” fülön keresztül vagy a hivatkozás megosztásával tud meghívni!",
    "Share this link to invite others!" : "Mások meghívásához ossza meg ezt a hivatkozást!",
    "Copy link" : "Hivatkozás másolása",
    "You are not allowed to enable audio" : "Nem engedélyezheti a hangot",
    "No audio. Click to select device" : "Nincs hang. Kattintson egy eszköz kiválasztásához",
    "Mute audio" : "Hang némítása",
    "Mute audio (M)" : "Hang némítása (M)",
    "Unmute audio" : "Hang némításának feloldása",
    "Unmute audio (M)" : "Hang némításának feloldása (M)",
    "None" : "Nincs",
    "Select a microphone" : "Válasszon mikrofont",
    "Select a speaker" : "Válasszon hangszórót",
    "Microphone settings" : "Mikrofonbeállítások",
    "Check devices" : "Eszközök ellenőrzése",
    "Access to camera was denied" : "A kamera hozzáférése letiltva",
    "Error while accessing camera: It is likely in use by another program" : "Hiba történt a kamera elérésekor: valószínűleg egy másik program használja",
    "Error while accessing camera" : "Hiba történt a kamera elérésekor",
    "You have been muted by a moderator" : "Egy moderátor elnémította Önt",
    "Hide presenter video" : "Előadó videójának elrejtése",
    "You are not allowed to enable video" : "Nem engedélyezheti a videót",
    "No video. Click to select device" : "Nincs videó. Kattintson egy eszköz kiválasztásához",
    "Disable video" : "Videó letiltása",
    "Disable video (V)" : "Videó letiltása (V)",
    "Enable video" : "Videó engedélyezése",
    "Enable video (V)" : "Videó engedélyezése (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Videó engedélyezése – A videó első bekapcsolásakor a kapcsolat rövid ideig meg fog szakadni",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Videó engedélyezése (V) – A videó első bekapcsolásakor a kapcsolat rövid ideig megszakad",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Videó engedélyezése. A videó első bekapcsolásakor a kapcsolat rövid ideig megszakad",
    "Select a video device" : "Válasszon videóeszközt",
    "Show presenter" : "Előadó megjelenítése",
    "You" : "Ön",
    "Mute" : "Némítás",
    "Muted" : "Némítva",
    "Show screen" : "Képernyő megjelenítése",
    "Stop following" : "Követés felfüggesztése",
    "Connection could not be established …" : "A kapcsolat nem hozható létre…",
    "Connection was lost and could not be re-established …" : "A kapcsolat elveszett, és nem hozható létre újra…",
    "Connection could not be established. Trying again …" : "A kapcsolat nem hozható létre. Újrapróbálkozás…",
    "Connection lost. Trying to reconnect …" : "A kapcsolat elveszett. Újrapróbálkozás…",
    "Connection problems …" : "Kapcsolódási problémák…",
    "Collapse" : "Összecsukás",
    "Expand" : "Kibontás",
    "You need to be logged in to upload files" : "A fájlok feltöltéséhez be kell jelentkeznie",
    "Drop your files to upload" : "Dobja ide a fájljait a feltöltéshez",
    "Conversation messages" : "Beszélgetési üzenetek",
    "Scroll to bottom" : "Görgetés az aljára",
    "Post message" : "Üzenet küldése",
    "Federated conversation" : "Föderált beszélgetés",
    "Public conversation" : "Nyilvános beszélgetés",
    "Favorite" : "Kedvenc",
    "Banned users" : "Kitiltott felhasználók",
    "Manage the list of banned users in this conversation." : "A kitiltott felhasználók kezelése ebben a beszélgetésben.",
    "Manage bans" : "Kitiltások kezelése",
    "No banned users" : "Nincs kitiltott felhasználó",
    "Banned by:" : "Kitiltotta:",
    "Date:" : "Dátum:",
    "Note:" : "Megjegyzés:",
    "Hide details" : "Részletek elrejtése",
    "Show details" : "Részletek megjelenítése",
    "Unban" : "Kitiltás visszavonása",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "A cím és a leírás a {linkstart}Naptárban ↗{linkend} változtatható meg.",
    "Error while updating conversation name" : "Hiba történt a beszélgetés nevének frissítése során",
    "Error while updating conversation description" : "Hiba történt a beszélgetés leírásának frissítése során",
    "Enter a name for this conversation" : "Adjon meg egy nevet a beszélgetéshez",
    "Edit conversation name" : "Beszélgetés nevének szerkesztése",
    "Edit conversation description" : "Beszélgetés leírásának szerkesztése",
    "Enter a description for this conversation" : "Adja meg a beszélgetés leírását",
    "Picture" : "Kép",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Ebben a beszélgetésben a következő botok engedélyezhetők. Forduljon a rendszergazdához, hogy több botot telepítsen erre a kiszolgálóra.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Nincs bot telepítve. Forduljon a rendszergazdához, hogy botot telepítsen erre a kiszolgálóra.",
    "Disable" : "Letiltás",
    "Enable" : "Engedélyezés",
    "Breakout rooms" : "Szétbontott szobák",
    "Manage breakout rooms" : "Szétbontott szobák kezelése",
    "Set up breakout rooms for this conversation" : "Szobabontás beállítása a beszélgetéshez",
    "Please select a valid PNG or JPG file" : "Válasszon egy érvényes PNG- vagy JPG-fájlt",
    "Choose your conversation picture" : "Válassza ki a beszélgetés képét",
    "Choose" : "Válasszon",
    "Error setting conversation picture" : "Hiba a beszélgetés képének beállítása során",
    "Could not set the conversation picture: {error}" : "Nem sikerült beállítani a beszélgetés képét: {error}",
    "Error cropping conversation picture" : "Hiba a beszélgetés képének levágása során",
    "Error removing conversation picture" : "Hiba a beszélgetés képének eltávolítása során",
    "Set emoji as conversation picture" : "Emodzsi beállítása a beszélgetés képének",
    "Set background color for conversation picture" : "Háttérszín beállítása a beszélgetés képénél",
    "Upload conversation picture" : "Beszélgetés képének feltöltése",
    "Choose conversation picture from files" : "Válassza ki a beszélgetés képét a fájlok közül",
    "Remove conversation picture" : "Beszélgetés képének eltávolítása",
    "The file must be a PNG or JPG" : "A képnek PNG-nek vagy JPG-nek kell lennie",
    "Set picture" : "Kép beállítása",
    "Default permissions modified for {conversationName}" : "A(z) {conversationName} alapértelmezett jogosultságai módosítva",
    "Could not modify default permissions for {conversationName}" : "A(z) {conversationName} alapértelmezett jogosultságai nem módosíthatók",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "A beszélgetés résztvevőinek alapértelmezett jogosultságainak szerkesztése. Ezek a beállítások nem érintik a moderátorokat.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Az egyes résztvevőkhöz rendelt egyéni jogosultságok elvesznek, ha módosítja a jogosultságokat ebben a szakaszban.",
    "All permissions" : "Összes jogosultság",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "A résztvevők elindíthatják a hívást, csatlakozhatnak egy meglévő híváshoz, engedélyezhetik a hangot, videót és a képernyőmegosztást.",
    "Restricted" : "Korlátozott",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "A résztvevők csatlakozhatnak a hívásokhoz, de addig nem engedélyezhetik a hangot, videót és képernyőmegosztást, míg egy moderátor kézzel nem adja meg nekik a jogosultságot.",
    "Advanced permissions" : "Speciális jogosultságok",
    "Edit permissions" : "Jogosultságok szerkesztése",
    "Conversation settings" : "Beszélgetésbeállítások",
    "Basic Info" : "Alapvető információk",
    "Personal" : "Személyes",
    "Moderation" : "Moderálás",
    "Setup overview" : "Telepítés áttekintése",
    "Live transcription" : "Élő leiratozás",
    "Live transcriptions app is not installed" : "Az Élő leiratozás alkalmazás nincs telepítve",
    "Enable live transcription" : "Élő leiratozás bekapcsolása",
    "Breakout Rooms" : "Szétbontott szobák",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Botok",
    "Danger zone" : "Veszélyes területet",
    "Archive conversation" : "Beszélgetés archiválása",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Az archivált beszélgetések alapértelmezetten rejtve vannak a beszélgetések közül. Viszont továbbra is megjelennek, ha a beszélgetés nevére keres, vagy ha az archivált beszélgetéseket éri el.",
    "Do you really want to leave \"{displayName}\"?" : "Biztos, hogy elhagyja ezt: „{displayName}”?",
    "You can archive this conversation instead." : "Ehelyett archiválhatja a beszélgetést.",
    "Leave conversation" : "Beszélgetés elhagyása",
    "You need to promote a new moderator before you can leave the conversation" : "Új moderátort kell kineveznie, mielőtt elhagyhatja a beszélgetést",
    "Delete conversation" : "Beszélgetés törlése",
    "Do you really want to delete \"{displayName}\"?" : "Biztos, hogy törli ezt: „{displayName}”?",
    "Error while deleting conversation" : "Hiba történt a beszélgetés törlése során",
    "Delete all chat messages" : "Összes csevegési üzenet törlése",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Biztos, hogy törli a következő összes üzenetét: „{displayName}”?",
    "Error while clearing chat history" : "Hiba a csevegés előzményeinek törlése során",
    "Be careful, these actions cannot be undone." : "Legyen óvatos, ezeket a műveleteket nem lehet visszavonni.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Ha elhagyott egy beszélgetést, akkor a zárt beszélgetésekhez visszacsatlakozáshoz meghívóra lesz szüksége. A nyílt beszélgetésekhez bármikor visszacsatlakozhat.",
    "Permanently delete this conversation." : "Beszélgetés végleges törlése.",
    "Delete chat messages" : "Csevegési üzenetek törlése",
    "Permanently delete all the messages in this conversation." : "A beszélgetés összes üzenetének végleges törlése.",
    "Custom expiration time" : "Egyéni elévülési idő",
    "Message expiration disabled" : "Az üzenetek elévülése ki van kapcsolva",
    "Message expiration set: {duration}" : "Üzenet elévülése beállítva: {duration}",
    "Error when trying to set message expiration" : "Hiba az üzenet lejáratának beállítása során",
    "Message expiration" : "Üzenetek elévülése",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "A csevegőüzenetek bizonyos idő után elévülhetnek. Megjegyzés: A csevegésben megosztott fájlok nem törlődnek a tulajdonosuk számára, csak többé nem lesznek megosztva a beszélgetéssel.",
    "Set message expiration" : "Üzenetek elévülésének beállítása",
    "Current message expiration" : "Jelenlegi üzenet elévülése",
    "Password copied to clipboard" : "A jelszó vágólapra másolva",
    "Password could not be copied" : "Nem sikerült a jelszó vágólapra másolása",
    "Guest access" : "Vendéghozzáférés",
    "Breakout rooms are not allowed in public conversations." : "A szétbontott szobák nyilvános beszélgetésekben nincsenek engedélyezve.",
    "Allow guests to join this conversation via link" : "Engedélyezés, hogy a vendégek hivatkozás használatával csatlakozhassanak a beszélgetéshez",
    "Password protection" : "Jelszavas védelem",
    "This conversation is password-protected. Guests need password to join" : "Ez a beszélgetés jelszóval van védve. A vendégeknek jelszó szükséges a csatlakozáshoz.",
    "Password protection is needed for public conversations" : "Jelszavas védelem szükséges a nyilvános beszélgetésekhez",
    "Set a password" : "Jelszó beállítása",
    "Change password" : "Jelszó módosítása",
    "Enter new password" : "Adjon meg egy új jelszót",
    "Save password" : "Jelszó mentése",
    "Copy password" : "Jelszó másolása",
    "Guests are allowed to join this conversation via link" : "A vendégek hivatkozáson keresztül csatlakozhatnak a beszélgetéshez",
    "Guests are not allowed to join this conversation" : "A vendégek nem csatlakozhatnak ehhez a beszélgetéshez",
    "Resend invitations" : "Meghívók újraköldése",
    "This conversation is open to both registered users and users created with the Guests app" : "Ez a beszélgetés nyitott a regisztrált felhasználók és a Guest alkalmazással létrehozott felhasználók számára",
    "This conversation is open to registered users" : "A beszélgetés nyitva van a regisztrált felhasználók számára",
    "This conversation is limited to the current participants" : "A beszélgetés a jelenlegi résztvevőkre van korlátozva",
    "You opened the conversation to both registered users and users created with the Guests app" : "Elindította a beszélgetést a regisztrált és a Vendégek alkalmazásban létrehozott felhasználók számára",
    "Error occurred when opening or limiting the conversation" : "Hiba történt a beszélgetés megnyitása vagy korlátozása során",
    "Open conversation to registered users, showing it in search results" : "Beszélgetés megnyitása a regisztrált felhasználók számára, megjelenítve a keresési találatok közt",
    "Also open to users created with the Guests app" : "Nyitva van a Vendégek alkalmazással létrehozott felhasználók számára is",
    "Open conversation" : "Beszélgetés megnyitása",
    "Set language spoken in calls" : "Hívásokban beszélt nyelv megadása",
    "Languages could not be loaded" : "Nem sikerült a nyelvek betöltése",
    "Loading languages …" : "Nyelvek betöltése…",
    "Invalid language" : "Érvénytelen nyelv",
    "Default language (English)" : "Alapértelmezett nyelv (angol)",
    "Default live transcription language set" : "Alapértelmezett élő leiratozási nyelv beállítva",
    "Live transcription language set: {languageName}" : "Beállított élő leiratozási nyelv: {languageName}",
    "Error when trying to set live transcription language" : "Hiba az élő leiratozási nyelv beállítása során",
    "Start time: {date}" : "Kezdési idő: {date}",
    "Start time has been updated" : "Kezdési idő módosítva",
    "Error occurred while updating start time" : "Hiba történt a kezdési idő frissítése során",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "A váró engedélyezése eltávolítja a nem moderátorokat a folyamatban lévő hívásból.",
    "Enable lobby, restricting the conversation to moderators" : "Váró engedélyezése, a beszélgetés moderátorokra korlátozása",
    "Meeting start time" : "A találkozó kezdési ideje",
    "Start time (optional)" : "Kezdési idő (nem kötelező)",
    "Import email participants" : "E-mail résztvevőinek importálása",
    "You can import a list of email participants from a CSV file." : "Importálhatja az e-mail résztvevőit egy CSV-fájlból.",
    "Poll drafts" : "Szavazásvázlatok",
    "Browse poll drafts" : "Szavazásvázlatok tallózása",
    "Error occurred when locking the conversation" : "Hiba történt a beszélgetés zárolása során",
    "Error occurred when unlocking the conversation" : "Hiba történt a beszélgetés feloldása során",
    "Lock conversation" : "Beszélgetés zárolása",
    "This will also terminate the ongoing call." : "Ezzel a folyamatban lévő hívás is megszakad.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "A beszélgetés zárolása, hogy senki se tudjon üzenetet küldeni vagy hívást indítani",
    "Edit" : "Szerkesztés",
    "More information" : "További információk",
    "Delete" : "Törlés",
    "Add new bridged channel to current conversation" : "Új összekötött csatorna hozzáadása az aktuális beszélgetéshez",
    "unknown state" : "ismeretlen állapot",
    "running" : "fut",
    "not running, check Matterbridge log" : "nem fut, ellenőrizze a Matterbridge naplóját",
    "not running" : "nem fut",
    "Bridge saved" : "Híd mentve",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "A Matterbridge segítségével összekötheti a különböző azonnali üzenetküldő rendszerek csatornáit.",
    "More info on Matterbridge" : "Bővebben a Matterbridge-ről",
    "Messaging systems" : "Üzenetküldő rendszerek",
    "Enable bridge" : "Híd engedélyezése",
    "Show Matterbridge log" : "Matterbridge napló megjelenítése",
    "Log content" : "Naplótartalom",
    "Only moderators are allowed to mention @all" : "Csak a moderátorok említhetik ezt meg: @all",
    "All participants are allowed to mention @all" : "Az összes résztvevő megemlítheti ezt: @all",
    "Participants are now allowed to mention @all." : "A résztvevők most már megemlíthetik ezt: @all.",
    "Mentioning @all has been limited to moderators." : "Már csak a moderátorok említhetik ezt meg: @all.",
    "Allow participants to mention @all" : "Engedélyezés, hogy a résztvevők megemlíthessék ezt: @all",
    "Mention permissions" : "Megemlítési engedély",
    "Notifications" : "Értesítések",
    "Notify about calls in this conversation" : "Értesítés a hívásokról ebben a beszélgetésben",
    "Important conversation" : "Fontos beszélgetés",
    "\"Do not disturb\" user status is ignored for important conversations" : "A „Ne zavarjanak” felhasználói állapot figyelmen kívül hagyása a fontos beszélgetéseknél",
    "Sensitive conversation" : "Érzékeny beszélgetés",
    "Message preview will be disabled in conversation list and notifications" : "Az üzenet-előnézet le lesz tiltva a beszélgetési listában és az értesítésekben",
    "Recording consent is required for calls in this conversation" : "Felvételi hozzájárulás szükséges a beszélgetés hívásaihoz",
    "Recording consent is not required for calls in this conversation" : "Nem szükséges a felvételi hozzájárulás a beszélgetés hívásaihoz",
    "Recording consent requirement was updated" : "A felvételi hozzájárulási követelmény frissítve lett",
    "Error occurred while updating recording consent" : "Hiba történt a felvételi hozzájárulás frissítése során",
    "Recording Consent" : "Felvételi hozzájárulás",
    "Recording consent cannot be changed once a call or breakout session has started." : "A felvételi hozzájárulás a hívás indítása vagy a szétbontott szobák létrehozása után nem módosítható.",
    "Require recording consent before joining call in this conversation" : "Hozzájárulás megkövetelése a beszélgetés hívásaihoz való csatlakozás előtt",
    "Recording consent is required for all calls" : "Hozzájárulás szükséges az összes hívás rögzítéséhez",
    "SIP dial-in is now possible without PIN requirement" : "A SIP-es betárcsázáshoz már nem szükséges PIN-kód",
    "SIP dial-in is now enabled" : "A SIP-es betárcsázás engedélyezett",
    "SIP dial-in is now disabled" : "A SIP-es betárcsázás nem engedélyezett",
    "Error occurred when enabling SIP dial-in" : "Hiba történt az SIP-es betárcsázás engedélyezése során",
    "Error occurred when disabling SIP dial-in" : "Hiba történt az SIP-es betárcsázás letiltása során",
    "Phone and SIP dial-in" : "Telefonos és SIP-es betárcsázás",
    "Enable phone and SIP dial-in" : "Telefonos és SIP-es betárcsázás engedélyezése",
    "Allow to dial-in without a PIN" : "PIN-kód nélküli betárcsázás engedélyezése",
    "Ongoing" : "Folyamatban",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n személy elfogadta","%n személy elfogadta"],
    "_%n person declined_::_%n people declined_" : ["%n személy elutasította","%n személy elutasította"],
    "_and %n other attachment_::_and %n other attachments_" : ["és %n egyéb melléklet","és %n egyéb melléklet"],
    "With {displayName}" : "Vele: {displayName}",
    "In {conversation}" : "Ebben: {conversation}",
    "View attachment" : "Melléklet megtekintése",
    "Join" : "Csatlakozás",
    "View conversation" : "Beszélgetés megtekintése",
    "View event on Calendar" : "Esemény megtekintése a Naptárban",
    "Error while creating the conversation" : "Hiba a beszélgetés létrehozásakor",
    "Hello, {displayName}" : "Üdv, {displayName}",
    "Start meeting now" : "Találkozó indítása most",
    "Give your meeting a title" : "Adjon címet a találkozónak",
    "Create and copy link" : "Hivatkozás létrehozása és másolása",
    "Create a new conversation" : "Új beszélgetés létrehozása",
    "Join open conversations" : "Csatlakozás a nyílt beszélgetésekhez",
    "Call a phone number" : "Telefonszám hívása",
    "Scroll backward" : "Görgetés visszafelé",
    "Scroll forward" : "Görgetés előrefelé",
    "Schedule meetings" : "Találkozók ütemezése",
    "You don't have any upcoming meetings" : "Nincsenek következő találkozók",
    "Open calendar" : "Naptár megnyitása",
    "Unread mentions" : "Olvasatlan említések",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Az üzenetek, melyekben megemlítették, itt fognak megjelenni. Másokat úgy említhet meg, hogy beírja a nevüket egy @ karakter után",
    "Upcoming reminders" : "Közelgő emlékeztetők",
    "Message reminders" : "Üzenetemlékeztetők",
    "Set a reminder on a message to be notified" : "Állítson be egy emlékeztetőt egy üzeneten, hogy értesítést kapjon",
    "Start a group conversation" : "Csoportos beszélgetés indítása",
    "Create conversation" : "Beszélgetés létrehozása",
    "Enter your name" : "Adja meg a nevét",
    "Submit name and join" : "Adjon meg nevet a csatlakozáshoz",
    "Do you already have an account?" : "Már van fiókja?",
    "Log in" : "Bejelentkezés",
    "Error while verifying uploaded file" : "Hiba a feltöltött fájl ellenőrzése során",
    "Uploaded file is verified" : "A feltöltött fájl ellenőrizve",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "A tartalom formátuma vesszővel elválasztott értékeket (CSV) használ:<br/>- A fejlécsor kötelező, és ezek egyikével kell megegyeznie: <samp>\"name\",\"email\"</samp> vagy csak <samp>\"email\"</samp><br/>- Soronként egy bejegyzés (például <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Résztvevők sikeresen hozzáadva",
    "Error while adding participants" : "Hiba a résztvevők hozzáadása során",
    "Import a file" : "Fájl importálása",
    "Browse" : "Tallózás",
    "Verifying uploaded file …" : "Feltöltött fájl ellenőrzése…",
    "This might take a moment" : "Ez eltarthat egy darabig",
    "Send invitations" : "Meghívók elküldése",
    "_%n invalid email_::_%n invalid emails_" : ["%n érvénytelen e-mail-cím","%n érvénytelen e-mail-cím"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n e-mail-cím már importálva lett, vagy ismétlődés","%n e-mail-cím már importálva lett, vagy ismétlődés"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n meghívó küldhető el","%n meghívó küldhető el"],
    "An error occurred while calling a phone number" : "Hiba történt egy telefonszám hívása során",
    "Phone number could not be called: {error}" : "A telefonszám nem hívható: {error}",
    "Phone number could not be called" : "A telefonszám nem hívható",
    "Search participants or phone numbers" : "Résztvevők vagy telefonszámok keresése",
    "Creating the conversation …" : "Új beszélgetés létrehozása…",
    "Mark as read" : "Megjelölés olvasottként",
    "Mark as unread" : "Megjelölés olvasatlanként",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "Unarchive conversation" : "Beszélgetés archiválásának visszavonása",
    "Ignore \"Do not disturb\"" : "A „Ne zavarjanak” jelzés figyelmen kívül hagyása",
    "You need to promote a new moderator before you can leave the conversation." : "Új moderátort kell kineveznie, mielőtt elhagyhatja a beszélgetést.",
    "New tag" : "Új címke",
    "Tag name" : "Címkenév",
    "Conversation actions" : "Beszélgetési műveletek",
    "Tags" : "Címkék",
    "Notify about calls" : "Értesítés a hívásokról",
    "Hide message text" : "Üzenetszöveg elrejtése",
    "Rename tag" : "Címke átnevezése",
    "Delete tag" : "Címke törlése",
    "Move up" : "Mozgatás fel",
    "Move down" : "Mozgatás le",
    "Pending invitations" : "Függőben lévő meghívások",
    "Join conversations from other servers" : "Csatlakozás beszélgetésekhez más kiszolgálókról",
    "From {user} at {remoteServer}" : "Feladó: {user} itt: {remoteServer}",
    "Decline invitation" : "Meghívás elutasítása",
    "Accept invitation" : "Meghívás elfogadása",
    "No pending invitations" : "Nincs függőben lévő meghívás",
    "Home" : "Kezdőlap",
    "Unread" : "Olvasatlan",
    "Mentions" : "Megemlítések",
    "Meetings" : "Találkozók",
    "Sort conversations" : "Beszélgetések rendezése",
    "By recent activity" : "Legfrissebb tevékenység",
    "Alphabetically" : "Betűrendben",
    "Do not group by type" : "Ne csoportosítsa típus szerint",
    "Show private ones first" : "Privátak megjelenítése elöl",
    "Show group ones first" : "Csoportosak megjelenítése elöl",
    "No followed threads" : "Nincs követett téma",
    "No matches found" : "Nincs találat",
    "No conversations found" : "Nem található beszélgetés",
    "You have no archived conversations." : "Nincs archivált beszélgetése.",
    "Subscribe to an existing thread or start your own." : "Iratkozzon fel egy meglévő szálra, vagy hozza létre a sajátját.",
    "You have no unread mentions." : "Nincs olvasatlan megemlítése.",
    "You have no unread messages." : "Nincs olvasatlan üzenet.",
    "An error occurred while performing the search" : "Hiba történt a keresés végrehajtása során",
    "Conversation list" : "Beszélgetések listája",
    "Filter conversations by" : "Témák szűrése:",
    "Unread messages" : "Olvasatlan üzenetek",
    "Meeting conversations" : "Találkozó beszélgetései",
    "Clear filters" : "Szűrők törlése",
    "New personal note" : "Új személyes jegyzet",
    "SIP backend is not installed" : "Nincs telepítve SIP háttérrendszer",
    "Back to conversations" : "Vissza a beszélgetésekhez",
    "Threads" : "Szálak",
    "Archived conversations" : "Archivált beszélgetések",
    "Clear filter" : "Szűrő törlése",
    "Show more threads" : "További szálak megjelenítése",
    "App settings" : "Alkalmazásbeállítások",
    "Users" : "Felhasználók",
    "Groups" : "Csoportok",
    "Teams" : "Csapatok",
    "Federated users" : "Föderált felhasználók",
    "New private conversation" : "Új privát beszélgetés",
    "Other sources" : "Egyéb források",
    "Open conversations" : "Beszélgetések megnyitása",
    "No search results" : "Nincs találat",
    "Users, groups and teams" : "Felhasználók, csoportok és csapatok",
    "Users and groups" : "Felhasználók és csoportok",
    "Users and teams" : "Felhasználók és csapatok",
    "Groups and teams" : "Csoportok és csapatok",
    "New group conversation" : "Új csoportos beszélgetés",
    "The meeting will start soon" : "Ez a találkozó hamarosan elkezdődik",
    "This meeting is scheduled for {startTime}" : "A találkozó ekkorra van ütemezve: {startTime}",
    "You are currently waiting in the lobby" : "Ön jelenleg a váróban van",
    "Enable noise suppression" : "Hangelnyomás bekapcsolása",
    "Reduce background noises for better voice quality" : "Csökkenti a háttérzajokat a jobb hangminőség érdekében",
    "Advanced" : "Speciális",
    "Enable echo cancellation" : "Visszhangkioltás bekapcsolása",
    "Minimize echo effect from own surrounding" : "Környezetből fakadó visszhanghatás minimalizálása",
    "Enable auto gain control" : "Automatikus erősítésvezérlés bekapcsolása",
    "Dynamically adjust microphone volume for consistent level" : "Mikrofon hangerejének dinamikus igazítása a konzisztens szint eléréséhez",
    "Select microphone" : "Mikrofon kiválasztása",
    "No microphone available" : "Nem áll rendelkezésre mikrofon",
    "Select speaker" : "Hangszóró kiválasztása",
    "No speaker available" : "Nem áll rendelkezésre hangszóró",
    "Select camera" : "Válasszon kamerát",
    "No camera available" : "Nem áll rendelkezésre kamera",
    "Select a device" : "Eszköz kiválasztása",
    "Playing …" : "Lejátszás…",
    "Test speakers" : "Hangszórók tesztelése",
    "Test" : "Teszt",
    "Devices" : "Eszközök",
    "Backgrounds" : "Hátterek",
    "No audio" : "Nincs hang",
    "No camera" : "Nincs kamera",
    "Display video as you will see it (mirrored)" : "Videó megjelenítése úgy, ahogy látni fogja (tükrözve)",
    "Display video as others will see it" : "Videó megjelenítése úgy, ahogy a többi látni fogják",
    "Calls are not supported in your browser" : "A böngészője nem támogatja a hívásokat",
    "Access to microphone is only possible with HTTPS" : "A mikrofon hozzáférése csak HTTPS-en lehetséges",
    "Access to microphone was denied" : "A mikrofon hozzáférése letiltva",
    "Error while accessing microphone" : "Hiba történt a mikrofon elérésekor",
    "Access to camera is only possible with HTTPS" : "A kamera hozzáférése csak HTTPS-en lehetséges",
    "The call is being recorded." : "A hívásról felvétel készül.",
    "The call might be recorded." : "A hívásról felvétel készülhet.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "A felvétel tartalmazhatja a hangját, a kamerája képet és a képernyőmegosztását. A híváshoz való csatlakozás előtt a hozzájárulása szükséges.",
    "Give consent to the recording of this call" : "Hozzájárulás, hogy felvétel készüljön a hívásról",
    "Show more info" : "További információk megjelenítése",
    "Audio is not available" : "Nem érhető el hang",
    "Video is not available" : "Nem érhető el videó",
    "Start recording immediately with the call" : "Felvétel indítása a hívás kezdetével",
    "Recording backend is not installed" : "Nincs telepítve a rögzítési háttérrendszer",
    "Notify all participants about this call" : "Összes résztvevő értesítése a hívásról",
    "Apply settings" : "Beállítások alkalmazása",
    "Select virtual office background" : "Virtuális irodai háttér kiválasztása",
    "Select virtual home background" : "Virtuális otthoni háttér kiválasztása",
    "Select virtual abstract background" : "Virtuális absztrakt háttér kiválasztása",
    "Select virtual beach background" : "Virtuális strandos háttér kiválasztása",
    "Select virtual park background" : "Virtuális parkos háttér kiválasztása",
    "Select virtual theater background" : "Virtuális színházi háttér kiválasztása",
    "Select virtual library background" : "Virtuális könyvtári háttér kiválasztása",
    "Select virtual space station background" : "Virtuális űrállomásos háttér kiválasztása",
    "Error while uploading the file" : "Hiba a fájl feltöltése során",
    "Select a file" : "Válasszon egy fájlt",
    "Invalid path selected" : "Érvénytelen útvonal kiválasztva",
    "Select virtual background from file {fileName}" : "Virtuális háttér kiválasztása fájlból: {fileName}",
    "Blur" : "Elmosás",
    "Upload" : "Feltöltés",
    "Files" : "Fájlok",
    "(editing)" : "(szerkesztés alatt)",
    "(edited)" : "(szerkesztve)",
    "The message has expired or has been deleted" : "Az üzenet elévült vagy törölték őket",
    "Cancel quote" : "Idézés megszakítása",
    "24 hours" : "24 óra",
    "7 days" : "7 nap",
    "30 days" : "30 nap",
    "Until unpin" : "Kitűzés megszüntetéséig",
    "Clear reminder – {timeLocale}" : "Emlékeztető törlése – {timeLocale}",
    "Edited by {actor}" : "Szerkesztette: {actor}",
    "Pinned by you" : "Ön tűzte ki",
    "Pinned by {actor}" : "{actor} tűzte ki",
    "Until {absoluteDate}" : "Eddig: {absoluteDate}",
    "Message text copied to clipboard" : "Az üzenet szövege kimásolva a vágólapra",
    "Message text could not be copied" : "Az üzenet szövege nem másolható",
    "Message forwarded to \"Note to self\"" : "Az üzenet továbbítva a „Saját jegyzetek” közé",
    "Error while forwarding message to \"Note to self\"" : "Hiba az üzenet „Saját jegyzetek” közé továbbítása során",
    "A reminder was successfully removed" : "Az emlékeztető sikeresen törölve lett",
    "Error occurred when removing a reminder" : "Hiba történt az emlékeztető eltávolítása során",
    "A reminder was successfully set at {datetime}" : "Az emlékeztető sikeresen be lett állítva: {datetime}",
    "Error occurred when creating a reminder" : "Hiba történt az emlékeztető létrehozása során",
    "Add a reaction to this message" : "Reakció hozzáadása az üzenethez",
    "Reply" : "Válasz",
    "More actions" : "További műveletek",
    "Set reminder" : "Emlékeztető beállítása",
    "Pin message" : "Üzenet kitűzése",
    "Unpin message" : "Üzenet kitűzésének megszüntetése",
    "Reply privately" : "Válasz privátban",
    "Edit message" : "Üzenet szerkesztése",
    "Copy message" : "Üzenet másolása",
    "Copy message link" : "Üzenethivatkozás másolása",
    "Go to file" : "Ugrás a fájlhoz",
    "Download file" : "Fájl letöltése",
    "Go to thread" : "Ugrás a szálhoz",
    "Edit thread details" : "Szál részleteinek szerkesztése",
    "Forward message" : "Üzenet továbbítása",
    "Translate" : "Lefordítás",
    "Set custom reminder" : "Egyéni emlékeztető beállítása",
    "Keep pinned for" : "Kitűzve tartás eddig:",
    "Set custom period" : "Egyéni időszak beállítása",
    "Close reactions menu" : "Reakciók menü bezárása",
    "React with {emoji}" : "Reagálás ezzel: {emoji}",
    "React with another emoji" : "Reagálás másik emodzsival",
    "Choose a conversation to forward the selected message." : "Válasszon egy beszélgetést a kiválasztott üzenet továbbításához.",
    "Error while forwarding message" : "Hiba az üzenet továbbítása során",
    "The message has been forwarded to {selectedConversationName}" : "Az üzenet továbbításra került ide: {selectedConversationName}",
    "Dismiss" : "Mellőzés",
    "Go to conversation" : "Ugrás a beszélgetéshez",
    "Detect language" : "Nyelv észlelése",
    "The message could not be translated" : "Az üzenetet nem sikerült lefordítani",
    "Translation copied to clipboard" : "A fordítás a vágólapra másolva",
    "Translation could not be copied" : "A fordítást nem lehetett másolni",
    "Translate message" : "Üzenet lefordítása",
    "Source language to translate from" : "Fordítás forrásnyelve",
    "Translate from" : "Fordítás a következőről:",
    "Target language to translate into" : "Fordítás célnyelve",
    "Translate to" : "Fordítás a következőre:",
    "Translating" : "Fordítás",
    "Copy translated text" : "Lefordított szöveg másolása",
    "Error when scheduling the message" : "Hiba az üzenet ütemezése során",
    "Reschedule" : "Újraütemezés",
    "Send now" : "Küldés most",
    "Choose a time" : "Válasszon egy időt",
    "Send at custom time" : "Küldés egyéni időben",
    "Will be sent without notification" : "Értesítés nélkül lesz elküldve",
    "Message read by everyone who shares their reading status" : "Az üzenetet mindenki olvasta, aki megosztja az olvasási állapotát",
    "Message sent" : "Üzenet elküldve",
    "Sent without notification" : "Értesítés nélkül elküldve",
    "Deleting message" : "Üzenet törlése",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Az üzenet sikeresen törölve, de a bot vagy a Matterbridge be van állítva, és lehet, hogy már el lett küldve más szolgáltatásokhoz",
    "Message deleted successfully" : "Az üzenet sikeresen törölve",
    "Message could not be deleted because it is too old" : "Az üzenetet nem sikerült törölni, mert túl régi",
    "Only normal chat messages can be deleted" : "Csak a normál csevegési üzeneteket lehet törölni",
    "An error occurred while deleting the message" : "Hiba történt az üzenet törlése során",
    "Pinned" : "Kitűzve",
    "Your browser does not support playing audio files" : "Böngészője nem támogatja a hangfájlok lejátszását",
    "Contact" : "Kapcsolat",
    "{stack} in {board}" : "{stack} itt: {board}",
    "Deck Card" : "Kártya",
    "Remove {fileName}" : "{fileName} eltávolítása",
    "Open this location in OpenStreetMap" : "Hely megnyitása az OpenStreetMapen",
    "_%n reply_::_%n replies_" : ["%n válasz","%n válasz"],
    "Sending message" : "Üzenet küldése",
    "Failed to send the message. Click to try again" : "Nem sikerült elküldeni az üzenetet. Kattintson az újrapróbálkozáshoz",
    "Not enough free space to upload file" : "Nincs elég szabad hely a fájl feltöltéséhez",
    "You cannot send messages to this conversation at the moment" : "Jelenleg nem küldhet üzeneteket erre a beszélgetésre",
    "Could not update the message" : "Nem sikerült az üzenet frissítése",
    "Reply to thread \"{threadTitle}\"" : "Válasz a(z) „{threadTitle}” szálban",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Szavazott • %n szavazat","Szavazott • %n szavazat"],
    "You voted" : "Szavazott",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Kattintson a szavazáshoz • %n szavazat","Kattintson a szavazáshoz • %n szavazat"],
    "Click to vote" : "Kattintson a szavazáshoz",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Szavazásvázlat • %n lehetőség","Szavazásvázlat • %n lehetőség"],
    "_%n vote_::_%n votes_" : ["%n szavazat","%n szavazat"],
    "Edit poll draft" : "Szavazásvázlat szerkesztése",
    "Delete poll draft" : "Szavazásvázlat törlése",
    "Open poll" : "Nyitott szavazás",
    "Closed poll" : "Zárt szavazás",
    "See results" : "Találatok megtekintése",
    "Reactions" : "Reakciók",
    "No permission to post reactions in this conversation" : "Nincs jogosultsága reakciókat használni ebben a beszélgetésben",
    "and {participant}" : "és {participant}",
    "_and %n other participant_::_and %n other participants_" : ["és %n másik résztvevő","és %n másik résztvevő"],
    "Show all reactions" : "Összes reakció megjelenítése",
    "Add more reactions" : "További reakciók hozzáadása",
    "Show or collapse system messages" : "Rendszerüzenetek megjelenítése vagy elrejtése",
    "No messages" : "Nincs üzenet",
    "All messages have expired or have been deleted." : "Az összes üzenet elévült vagy törölték őket.",
    "Generate summary with AI" : "Összefoglaló előállítása MI-vel",
    "{author} (pinned by you)" : "{author} (Ön tűzte ki)",
    "{author} (pinned by {actor})" : "{author} ({actor} tűzte ki)",
    "Unpin" : "Rögzítés feloldása",
    "Cancel search" : "Keresés megszakítása",
    "Add a phone number" : "Telefonszám hozzáadása",
    "Error: A password is required to create the conversation." : "Hiba: Jelszó szükséges a beszélgetés létrehozásához.",
    "All set, the conversation \"{conversationName}\" was created." : "Minden kész, a(z) „{conversationName}” beszélgetés létrejött.",
    "Create a new group conversation" : "Új csoportbeszélgetés létrehozása",
    "Add participants" : "Résztvevők hozzáadása",
    "Maximum length exceeded ({maxlength} characters)" : "Legnagyobb hossz túllépve ({maxlength} karakter)",
    "Conversation visibility" : "Beszélgetés láthatósága",
    "Allow guests to join via link" : "A vendégek hivatkozással történő csatlakozásának engedélyezése",
    "Enter password" : "Adja meg a jelszót",
    "This conversation has been locked" : "A beszélgetés zárolva van",
    "No permission to post messages in this conversation" : "Nincs jogosultsága megjegyzést fűzni a beszélgetéshez",
    "Joining conversation …" : "Csatlakozás a beszélgetéshez…",
    "Write a message without notification" : "Üzenet írása értesítés nélkül",
    "Create a thread silently" : "Szál létrehozása némán",
    "Create a thread" : "Szál létrehozása",
    "Send message silently" : "Üzenet küldése némán",
    "Send message" : "Üzenet küldése",
    "Send without notification" : "Küldés értesítés nélkül",
    "The participant will not be notified about new messages" : "A résztvevő nem lesz értesítve az új üzenetekről",
    "Participants will not be notified about new messages" : "A résztvevők nem lesznek értesítve az új üzenetekről",
    "Message will be sent {datetimeString}" : "Az üzenet ekkor lesz elküldve: {datetimeString}",
    "Thread title is required" : "A szál címe kötelező",
    "Message text is required" : "Az üzenet szövege kötelező",
    "The message could not be edited" : "Az üzenet nem szerkeszthető",
    "File to share" : "Fájl megosztása",
    "File upload is not available in this conversation" : "A fájlfeltöltés elérhető ebben a beszélgetésben",
    "Message was successfully scheduled" : "Az üzenet sikeresen be lett ütemezve",
    "Add emoji" : "Emodzsi hozzáadása",
    "Adding a mention will only notify users who did not read the message." : "A megemlítés csak azokat a felhasználókat fogja értesíteni, akik nem olvasták az üzenetet.",
    "Thread title" : "Szál címe",
    "Send later" : "Küldés később",
    "Show scheduled messages" : "Ütemezett üzenetek megjelenítése",
    "Cancel editing" : "Szerkesztés megszakítása",
    "Schedule message" : "Üzenet ütemezése",
    "{user} is out of office and might not respond." : "{user} házon kívül van, és lehet, hogy nem fog válaszolni.",
    "Absence period: {startDate} - {endDate}" : "Házon kívüli időszak: {startDate} – {endDate}",
    "Replacement:" : "Helyettes:",
    "Share from {nextcloud}" : "Megosztás innen: {nextcloud}",
    "Share from Files" : "Megosztás a Fájlokból",
    "Share files to the conversation" : "Fájlok megosztása a beszélgetéssel",
    "Upload from device" : "Feltöltés az eszközről",
    "Create new poll" : "Új szavazás létrehozása",
    "Smart picker" : "Okos választó",
    "Record voice message" : "Hangüzenet rögzítése",
    "End recording and send" : "Felvétel befejezése és küldés",
    "Dismiss recording" : "Felvétel elvetése",
    "Access to the microphone was denied" : "A mikrofon hozzáférése letiltva",
    "Microphone either not available or disabled in settings" : "A mikrofon nem érhető el, vagy le lett tiltva a beállításokban",
    "Error while recording audio" : "Hiba a hang felvétele során",
    "Voice message {time} ({conversation})" : "Hangüzenet {time} ({conversation})",
    "Generating summary of unread messages …" : "Összefoglaló előállítása az olvasatlan üzenetekről…",
    "Summary is AI generated and might contain mistakes" : "Az összefoglalót MI állítja elő, és hibákat tartalmazhat",
    "Error occurred during a summary generation" : "Hiba az összefoglaló előállítása során",
    "New file" : "Új fájl",
    "Blank" : "Üres",
    "Error while creating file" : "Hiba a fájl létrehozása során",
    "Create and share a new file" : "Új fájl létrehozása és megosztása",
    "Name of the new file" : "Az új fájl neve",
    "Create file" : "Fájl létrehozása",
    "Someone is typing …" : "Valaki gépel…",
    "{user1} is typing …" : "{user1} gépel…",
    "{user1} and {user2} are typing …" : "{user1} és {user2} gépelnek…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} és {user3} gépelnek…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} és még %n felhasználó gépel…","{user1}, {user2}, {user3} és még %n felhasználó gépel…"],
    "Add more files" : "Több fájl hozzáadása",
    "Send" : "Küldés",
    "In this conversation <strong>{user}</strong> can:" : "Ebben a beszélgetésben <strong>{user}</strong> a következőket teheti:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "A(z) <strong>{conversationName}</strong> résztvevőinek alapértelmezett jogosultságának szerkesztése",
    "Start a call" : "Hívás indítása",
    "Skip the lobby" : "Váró kihagyása",
    "Can post messages" : "Közzéteget üzeneteket",
    "Can post messages and reactions" : "Közzétehet bejegyzéseket és használhat reakciókat",
    "Can add reactions" : "Adhat hozzá reakciókat",
    "Enable the microphone" : "Mikrofon engedélyezése",
    "Enable the camera" : "Kamera engedélyezése",
    "Share the screen" : "Képernyő megosztása",
    "Update permissions" : "Jogosultságok frissítése",
    "Updating permissions" : "Jogosultságok frissítése",
    "No poll drafts" : "Nincs szavazásvázlat",
    "There is no poll drafts yet saved for this conversation" : "Még nincs mentett szavazásvázlat ehhez a beszélgetésben",
    "Create poll in {name}" : "Szavazás létrehozása itt: {name}",
    "Create poll" : "Szavazás létrehozása",
    "Error while importing poll" : "Hiba a szavazás importálása során",
    "Question" : "Kérdés",
    "Ask a question" : "Kérdés feltevése",
    "Import draft from file" : "Vázlat importálása fájlból",
    "Answers" : "Válaszok",
    "Answer {option}" : "{option}. válasz",
    "Delete poll option" : "Szavazási lehetőség törlése",
    "Add answer" : "Válasz hozzáadása",
    "Settings" : "Beállítások",
    "Anonymous poll" : "Névtelen szavazás",
    "Multiple answers" : "Több válasz",
    "Save as draft" : "Mentés vázlatként",
    "Export draft to file" : "Vázlat exportálása fájlba",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Végső eredmények • %n szavazat","Végső eredmények • %n szavazat"],
    "Your vote is anonymous" : "A szavazata anonim",
    "You voted for this option" : "Erre a lehetőségre szavazott",
    "End poll" : "Szavazás befejezése",
    "Change your vote" : "Szavazat módosítása",
    "Withdraw vote" : "Szavazat visszavonása",
    "Results" : "Eredmények",
    "Voted participants" : "Résztvevők, akik szavaztak",
    "Send a message to \"{roomName}\"" : "Üzenet küldése ide: „{roomName}”",
    "Hide list of participants" : "Résztvevők elrejtése",
    "Show list of participants" : "Résztvevők megjelenítése",
    "Assistance requested in {roomName}" : "Segítség kérve itt: {roomName}",
    "The message was sent to \"{roomName}\"" : "Az üzenet el lett küldve ide: „{roomName}”",
    "Dismiss request for assistance" : "A segítségkérés elvetése",
    "Send message to room" : "Üzenet küldése a szobának",
    "Back to main room" : "Vissza a fő szobába",
    "Back to your room" : "Vissza a saját szobába",
    "Message all rooms" : "Üzenet az összes szobának",
    "Start session" : "Munkamenet indítása",
    "Start a call before you start a breakout room session" : "Indítson el egy hívást mielőtt szétbontott szobákat készít",
    "Stop session" : "Munkamenet leállítása",
    "The message was sent to all breakout rooms" : "Az üzenet el lett küldve az összes szétbontott szobának",
    "Send a message to all breakout rooms" : "Üzenet küldése az összes szétbontott szobának",
    "Breakout rooms are not started" : "A szétbontott szobák nem lettek elindítva",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "A Nagy teljesítményű háttérrendszer nélküli hívások kapcsolódási problémákat és magas terhelést okozhatnak az eszközökön. {linkstart}További információ{linkend}",
    "Talk setup incomplete" : "A Beszélgetés beállítása nem teljes",
    "Disable lobby" : "A váró letiltása",
    "Settings for participant \"{user}\"" : "„{user}” résztvevő beállításai",
    "Participant \"{user}\"" : "„{user}” résztvevő",
    "moderator" : "moderátor",
    "bot" : "bot",
    "guest" : "vendég",
    "Ringing …" : "Csengetés…",
    "Call rejected" : "Hívás elutasítva",
    "{time} talking …" : "{time}, hívásban…",
    "{time} talking time" : "{time} beszélgetési idő",
    "Raised their hand" : "Felemelte a kezét",
    "Joined with video" : "Videóval csatlakozott",
    "Joined via phone" : "Telefonon csatlakozott",
    "Joined with audio" : "Hanggal csatlakozott",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "A szöveg legfeljebb {maxLength} karakteres lehet. Jelenlegi szövege {charactersCount} karakter hosszú.",
    "Remove group and members" : "Csoport és tagjainak eltávolítása",
    "Remove team and members" : "Csapat és tagjainak eltávolítása",
    "Remove participant" : "Résztvevő eltávolítása",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Biztos, hogy eltávolítja a(z) „{displayName}” csoportot és a tagjait ebből a beszélgetésből?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Biztos, hogy eltávolítja a(z) „{displayName}” csapatot és a tagjait ebből a beszélgetésből?",
    "Do you really want to remove {displayName} from this conversation?" : "Biztos, hogy eltávolítja a következőt ebből a beszélgetésből: „{displayName}”?",
    "Notification was sent to {displayName}" : "Az értesítés elküldve {displayName} számára",
    "Could not send notification to {displayName}" : "Nem sikerült elküldeni az értesítést {displayName} számára",
    "Permissions granted to {displayName}" : "Jogosultságok megadva {displayName} számára",
    "Could not modify permissions for {displayName}" : "{displayName} jogosultságai nem módosíthatók",
    "Permissions removed for {displayName}" : "{displayName} jogosultságai eltávolítva",
    "Permissions set to default for {displayName}" : "{displayName} jogosultságai alapértékekre állítva",
    "Phone number could not be hung up" : "A telefonszám nem tehető le",
    "Phone number could not be put on hold" : "A telefonszám nem tehető tartásba",
    "Phone number could not be muted" : "A telefonszám nem némítható",
    "Phone number could not be unmuted" : "A telefonszám némítása nem vonható vissza",
    "DTMF message could not be sent" : "A DTMF-üzenet nem küldhető el",
    "Phone number copied to clipboard" : "A telefonszám nem másolható a vágólapra",
    "Phone number could not be copied" : "A telefonszám nem másolható",
    "in the lobby" : "a váróban",
    "Dial out phone" : "Telefon tárcsázása",
    "Hang up phone" : "Telefon letevése",
    "Move back to lobby" : "Áthelyezés a váróba",
    "Move to conversation" : "Áthelyezés a beszélgetésbe",
    "Dial-in PIN" : "Telefonos PIN",
    "Demote from moderator" : "Lefokozás moderátorról",
    "Promote to moderator" : "Kinevezés moderátorrá",
    "Resend invitation" : "Meghívó újraküldése",
    "Send call notification" : "Hívásértesítés küldése",
    "Dial out phone number" : "Telefonszám tárcsázása",
    "Resume call for phone number" : "Telefonszám hívásának folytatása",
    "Put phone number on hold" : "Telefonszám tartásba tevése",
    "Unmute phone number" : "Telefonszám némításának visszavonása",
    "Mute phone number" : "Telefonszám némítása",
    "Copy phone number" : "Telefonszám másolása",
    "Reset custom permissions" : "Egyéni engedélyek visszaállítása",
    "Grant all permissions" : "Összes jogosultság megadása",
    "Remove all permissions" : "Összes jogosultság eltávolítása",
    "Also ban from this conversation" : "Egyúttal kitiltás ebből a beszélgetésből",
    "Internal note (reason to ban)" : "Belső jegyzet (kitiltás oka)",
    "Remove" : "Eltávolítás",
    "Permissions modified for {displayName}" : "{displayName} jogosultságai módosítva",
    "Add users, groups or teams" : "Felhasználók, csoportok vagy csapatok hozzáadása",
    "Add users or groups" : "Felhasználók vagy csoportok hozzáadása",
    "Add users or teams" : "Felhasználók vagy csapatok hozzáadása",
    "Add users" : "Felhasználók hozzáadása",
    "Add groups or teams" : "Csoportok vagy csapatok hozzáadása",
    "Add groups" : "Csoportok hozzáadása",
    "Add teams" : "Csapatok hozzáadása",
    "Add other sources" : "További források hozzáadása",
    "Add emails" : "E-mailek hozzáadása",
    "Integrations" : "Integrációk",
    "Add federated users" : "Föderált felhasználók hozzáadása",
    "Searching …" : "Keresés…",
    "Search for more users" : "További felhasználók keresése",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Kereshet és hozzáadhat résztvevőket név, e-mail-cím vagy föderált felhőazonosító alapján",
    "Search or add participants" : "Résztvevők keresése vagy hozzáadása",
    "Invitation was sent to {actorId}" : "Meghívó elküldve a következőnek: {actorId}",
    "An error occurred while adding the participants" : "Hiba történt a résztvevők hozzáadása során",
    "A new group conversation with selected participant will be created" : "Egy új csoportos beszélgetés lesz létrehozva a kiválasztott résztvevővel",
    "Participants" : "Résztvevők",
    "Pinned by a deleted user" : "Törölt felhasználó tűzte ki",
    "Participants ({count})" : "Résztvevők ({count})",
    "Open chat" : "Csevegés megnyitása",
    "You have new unread messages in the chat." : "Olvasatlan üzenetek vannak a csevegésben.",
    "You have been mentioned in the chat." : "Megemlítették a csevegésben.",
    "Search messages" : "Üzenetek keresése",
    "Chat" : "Csevegés",
    "Details" : "Részletek",
    "Shared items" : "Megosztott elemek",
    "Search in {name}" : "Keresés itt: {name}",
    "Threads in {name}" : "Szálak itt: {name}",
    "{actor} in {conversation}" : "{actor} itt: {conversation}",
    "Search messages …" : "Üzenetek keresése…",
    "Search options" : "Keresési lehetőségek",
    "From User" : "Feladó",
    "Since" : "Ettől",
    "Until" : "Eddig",
    "No results found" : "Nincs találat",
    "Load more results" : "További találatok betöltése",
    "Recent threads" : "Legutóbbi szálak",
    "Projects" : "Projektek",
    "No shared items" : "Nincsenek megosztott elemek",
    "Thread notifications" : "Szálértesítések",
    "Thread actions" : "Szálműveletek",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Hivatkozás egy beszélgetéshez",
    "No open conversations found" : "Nem található nyitott beszélgetés",
    "Either there are no open conversations or you joined all of them." : "Nincs nyitott beszélgetés, vagy már az összeshez csatlakozott.",
    "Check spelling or use complete words." : "Ellenőrizze a helyesírást, vagy használjon teljes szavakat.",
    "Search conversations or users" : "Beszélgetések vagy felhasználók keresése",
    "Select conversation" : "Válasszon beszélgetést",
    "Number length is not valid" : "A szám hossza nem érvényes",
    "Region code is not valid" : "A régiókód nem érvényes",
    "Number length is too short" : "A szám hossza túl rövid",
    "Number length is too long" : "A szám hossza túl hosszú",
    "Number is not valid" : "A szám nem érvényes",
    "Phone numbers" : "Telefonszámok",
    "Display name: {name}" : "Megjelenítendő név: {name}",
    "Edit display name" : "Megjelenítendő név szerkesztése",
    "Display name (required)" : "Megjelenítendő név (kötelező)",
    "Save name" : "Név mentése",
    "I picked message bubbles" : "Üzenetbuborékokat választottam",
    "I picked the list style" : "Listastílust választottam",
    "Error while setting personal setting" : "Hiba a személyes beállítása mentése során",
    "Error while saving sounds setting" : "Hiba a hangbeállítások mentése során",
    "Compact conversations list" : "Kompakt beszélgetéslista",
    "Chat appearance" : "Csevegés megjelenése",
    "Messages list" : "Üzenetlista",
    "Message bubbles" : "Üzenetbuborékok",
    "Play sounds when participants join or leave a call" : "Hangjelzések lejátszása, amikor a résztvevők csatlakoznak, vagy elhagyják a hívást",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "A gyártó műszaki korlátozásai miatt jelenleg nem érhető el iPhone és iPad eszközökön",
    "Notification settings" : "Értesítési beállítások",
    "Sounds for chat and call notifications" : "Hangok a csevegési és hívásértesítésekhez",
    "Invalid language ({languageId})" : "Érvénytelen nyelv ({languageId})",
    "Default language" : "Alapértelmezett nyelv",
    "Default language ({languageName})" : "Alapértelmezett nyelv ({languageName})",
    "Error when trying to load the available live translation languages" : "Hiba történt az elérhető élő fordítási nyelvek betöltése során",
    "Error when trying to set live translation language" : "Hiba történt az élő fordítás nyelvének beállítása során",
    "Set language used to show the transcriptions" : "A leiratozás megjelenítéséhez használt nyelv beállítása",
    "Select location for attachments" : "Válassza ki a mellékletek helyét",
    "Error while setting attachment folder" : "Hiba a mellékletek mappa beállításakor",
    "Error while setting read status privacy" : "Hiba történt az olvasási állapot adatvédelmi beállításakor",
    "Error while setting typing status privacy" : "Hiba történt a gépelési állapot adatvédelmi beállításakor",
    "Error while setting default media state" : "Hiba az alapértelmezett médiaállapot beállítása során",
    "Turn camera and microphone off by default" : "Kamera és mikrofon alapértelmezett kikapcsolása",
    "Blur camera background by default" : "Kamera hátterének alapértelmezett elmosása",
    "Skip device preview before joining a call" : "Eszköz-előnézet kihagyása híváshoz való csatlakozás előtt",
    "Appearance & Sounds" : "Megjelenés és hangok",
    "Privacy" : "Adatvédelem",
    "Send read receipts" : "Olvasási visszajelzés küldése",
    "When off, all read statuses will be hidden" : "Ha ki van kapcsolva, az összes olvasási állapot rejtve lesz",
    "Share typing status" : "Gépelési állapot megosztása",
    "When off, all typing indicators will be hidden" : "Ha ki van kapcsolva, az összes gépelési visszajelzés rejtve lesz",
    "Attachments folder" : "Mellékletek mappa",
    "Toggle full screen" : "Teljes képernyő be/ki",
    "Return to Home screen" : "Visszatérés a kezdőképernyőre",
    "Search" : "Keresés",
    "Shortcuts while in a chat" : "Billentyűparancsok csevegés közben",
    "Focus the chat input" : "Fókusz a csevegés beviteli mezőjére",
    "Unfocus the chat input to use shortcuts" : "A billentyűparancsok használatához hagyja el a csevegés beviteli mezőjét",
    "Edit your last message" : "Utolsó saját üzenet szerkesztése",
    "Shortcuts while in a call" : "Billentyűparancsok hívás közben",
    "Camera on and off" : "Kamera be- és kikapcsolása",
    "Microphone on and off" : "Mikrofon be- és kikapcsolása",
    "Raise or lower hand" : "Kéz felemelése vagy leengedése",
    "Push to talk or push to mute" : "Lenyomásra történő beszéd vagy némítás",
    "Zoom-in / zoom-out a screen share" : "Nagyítás/kicsinyítés képernyőmegosztáskor",
    "Mouse wheel" : "Egérgörgő",
    "Start call silently" : "Hívás indítása némán",
    "Start call" : "Hívás indítása",
    "End call" : "Hívás befejezése",
    "The server was updated, you cannot start or join a call." : "A kiszolgáló frissítve lett, nem indíthat vagy csatlakozhat híváshoz.",
    "This call has just ended" : "Ez a hívás véget ért",
    "You will be able to join the call only after a moderator starts it." : "Csak akkor csatlakozhat a híváshoz, ha azt egy moderátor elindítja.",
    "End call for everyone" : "Hívás befejezése mindenki számára",
    "Starting the recording" : "A felvétel indítása",
    "Recording" : "Felvétel",
    "The call has been running for one hour." : "A hívás egy órája tart.",
    "Cancel recording start" : "Felvétel indításának megszakítása",
    "Stop recording" : "Felvétel leállítása",
    "Raise hand" : "Kéz felemelése",
    "Raise hand (R)" : "Kéz felemelése (R)",
    "Lower hand" : "Kéz letétele",
    "Lower hand (R)" : "Kéz letétele (R)",
    "Send a reaction" : "Reakció küldése",
    "React with {reaction}" : "Reagálás ezzel: {reaction}",
    "All tasks done!" : "Az összes feladat kész!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done}/%n feladat","{done}/%n feladat"],
    "Add participants to this call" : "Résztvevők hozzáadása a híváshoz",
    "_%n participant in call_::_%n participants in call_" : ["%n résztvevő a hívásban","%n résztvevő a hívásban"],
    "Scheduled messages" : "Ütemezett üzenetek",
    "You are not allowed to enable screensharing" : "Nem engedélyezheti a képernyőmegosztást",
    "No screensharing" : "Nincs képernyőmegosztás",
    "Screensharing options" : "Képernyőmegosztás beállításai",
    "Enable screensharing" : "Képernyőmegosztás engedélyezése",
    "Bad sent video and screen quality." : "Rossz a küldött videó és képernyő minősége.",
    "Bad sent screen quality." : "Rossz a küldött képernyő minősége.",
    "Bad sent video quality." : "Rossz a küldött videó minősége.",
    "Bad sent audio, video and screen quality." : "Rossz a küldött hang, videó és képernyő minősége.",
    "Bad sent audio and screen quality." : "Rossz a küldött hang és képernyő minősége.",
    "Bad sent audio and video quality." : "Rossz a küldött hang és videó minősége.",
    "Bad sent audio quality." : "Rossz a küldött hang minősége.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem láthatják az Ön képernyőjét. A helyzet javítása érdekében próbálja meg letiltani a háttér elmosását vagy a videót képernyőmegosztás közben.",
    "Disable background blur" : "Háttér elmosásának kikapcsolása",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem láthatják az Ön képernyőjét. A helyzet javítása érdekében próbálja meg letiltani a videót képernyőmegosztás közben.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem láthatják a képernyőt.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem láthatják Önt.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem fogják megérteni és látni Önt. A helyzet javítása érdekében próbálja meg letiltani a háttér elmosását vagy a videót képernyőmegosztás közben.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem fogják megérteni és látni Önt. A helyzet javítása érdekében próbálja meg letiltani a videót képernyőmegosztás közben.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem fogják megérteni Önt és nem láthatják a képernyőt. A helyzet javítása érdekében próbálja meg letiltani a képernyőmegosztást.",
    "Disable screenshare" : "Képernyőmegosztás letiltása",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem fogják megérteni és látni Önt. A helyzet javítása érdekében próbálja meg letiltani a háttér elmosását vagy a videót.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem fogják megérteni és látni. A helyzet javítása érdekében próbálja meg letiltani a videót.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Internetkapcsolata vagy számítógépe foglalt, és elképzelhető, hogy más résztvevők nem fogják megérteni Önt.",
    "Screen sharing is not supported by your browser." : "A böngészője nem támogatja a képernyőmegosztást.",
    "Screen sharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz az oldalt HTTPS-en keresztül kell betölteni.",
    "Screensharing requires the page to be loaded through HTTPS." : "A képernyőmegosztáshoz az oldalt HTTPS-en keresztül kell betölteni.",
    "An error occurred while starting screensharing." : "Hiba történt a képernyő megosztásakor.",
    "Select virtual background" : "Válasszon virtuális hátteret",
    "Show your screen" : "Saját képernyő megosztása",
    "Stop screensharing" : "Képernyőmegosztás befejezése",
    "Mute others" : "Mások elnémítása",
    "Start recording" : "Felvétel indítása",
    "Set up breakout rooms" : "Szétbontott szobák beállítása",
    "Download attendance list" : "Résztvevők listájának letöltése",
    "Open Calendar" : "Naptár megnyitása",
    "Remove participant {name}" : "Résztvevő eltávolítása: {name}",
    "Would you like to delete this conversation?" : "Törli ezt a beszélgetést?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Ez a beszélgetés %n nap tétlenség után mindenki számára törölve lesz.","Ez a beszélgetés %n nap tétlenség után mindenki számára törölve lesz."],
    "Are you sure you want to delete this conversation?" : "Biztos, hogy törli ezt a beszélgetést?",
    "Delete now" : "Törlés most",
    "Keep" : "Megtartás",
    "Open dialpad" : "Tárcsázó megnyitása",
    "Select a region" : "Válasszon régiót",
    "Local time: {time}" : "Helyi idő: {time}",
    "Scheduled {datetime}" : "Ütemezve: {datetime}",
    "Scheduled for {datetime}" : "Ütemezve: {datetime}",
    "Search …" : "Keresés…",
    "Message without mention" : "Üzenet megemlítés nélkül",
    "Mention myself" : "Saját magam megemlítése",
    "Mention everyone" : "Mindenki megemlítése",
    "Select a conversation" : "Beszélgetés kiválasztása",
    "Select a mode" : "Mód kiválasztása",
    "You do not have permissions to access this conversation." : "Nincs jogosultsága, hogy elérje ezt a beszélgetést.",
    "Join a different conversation or start a new one." : "Csatlakozás egy másik beszélgetéshez, vagy új indítása.",
    "The conversation does not exist" : "A beszélgetés nem létezik",
    "Join a conversation or start a new one!" : "Csatlakozzon egy beszélgetéshez, vagy indítson egy újat!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Ez a beszélgetés egy másik lapon meg lett nyitva. A kiszolgáló jelenlegi verziója nem támogatja a beszélgetések több lapon való megjelenítését.",
    "Creating and joining a conversation with \"{userid}\"" : "Beszélgetés létrehozása „{userid}” felhasználóval, és csatlakozás",
    "Join a conversation or start a new one" : "Csatlakozzon egy beszélgetéshez vagy indítson egy újat",
    "Error while joining the conversation" : "Hiba a beszélgetéshez való csatlakozás során",
    "Another user" : "Másik felhasználó",
    "Hey! Are you using the list style or message bubbles?" : "Hé! Listastílust vagy üzenetbuborékokat használsz?",
    "Nextcloud URL" : "Nextcloud webcíme",
    "Nextcloud user" : "Nextcloud-felhasználó",
    "User password" : "Felhasználói jelszó",
    "Talk conversation" : "Beszélgetés",
    "Skip TLS verification" : "A TLS-ellenőrzés kihagyása",
    "Matrix server URL" : "Matrix-kiszolgáló webcíme",
    "User" : "Felhasználó",
    "Matrix channel" : "Matrix-csatorna",
    "Mattermost server URL" : "Mattermost-kiszolgáló webcíme",
    "Mattermost user" : "Mattermost felhasználó",
    "Team name" : "Csapat neve",
    "Channel name" : "Csatorna neve",
    "Rocket.Chat server URL" : "Rocket.Chat kiszolgáló webcíme",
    "User name or email address" : "Felhasználónév vagy e-mail-cím",
    "Rocket.Chat channel" : "Rocket.Chat csatorna",
    "Zulip server URL" : "Zulip kiszolgáló webcíme",
    "Bot user name" : "Bot felhasználónév",
    "Bot API key" : "Bot API kulcs",
    "Zulip channel" : "Zulip csatorna",
    "API token" : "API token",
    "Slack channel" : "Slack csatorna",
    "Server ID or name" : "Kiszolgálóazonosító vagy név",
    "Channel ID (prefixed with \"ID:\") or name" : "Csatornaazonosító („ID:” előtaggal) vagy név",
    "Channel" : "Csatorna",
    "Login" : "Bejelentkezés",
    "Chat ID" : "Csevegésazonosító",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC-kiszolgáló webcíme (pl. chat.freenode.net:6667)",
    "Nickname" : "Becenév",
    "Connection password" : "Csatlakozási jelszó",
    "IRC channel" : "IRC csatorna",
    "Channel password" : "Csatorna jelszó",
    "NickServ nickname" : "NickServ becenév",
    "NickServ password" : "NickServ jelszó",
    "Use TLS" : "TSL használata",
    "Use SASL" : "SASL használata",
    "Tenant ID" : "Ügyfél-azonosító",
    "Client ID" : "Kliensazonosító",
    "Team ID" : "Csapatazonosító",
    "Thread ID" : "Szálazonosító",
    "XMPP/Jabber server URL" : "XMPP/Jabber-kiszolgáló webcíme",
    "MUC server URL" : "MUC kiszolgáló webcíme",
    "Jabber ID" : "Jabber azonosító",
    "Pinned messages" : "Kitűzött üzenetek",
    "Media" : "Média",
    "Polls" : "Szavazások",
    "Deck cards" : "Kártyák",
    "Voice messages" : "Hangüzenetek",
    "Locations" : "Helyek",
    "Call recordings" : "Hívásfelvételek",
    "Audio" : "Hangok",
    "Show all pinned messages" : "Összes kitűzött üzenet megjelenítése",
    "Show all media" : "Összes média megjelenítése",
    "Show all files" : "Összes fájl megjelenítése",
    "Show all polls" : "Összes szavazás megjelenítése",
    "Show all deck cards" : "Összes kártya megjelenítése",
    "Show all voice messages" : "Összes hangüzenet megjelenítése",
    "Show all locations" : "Összes hely megjelenítése",
    "Show all call recordings" : "Az összes hívásfelvétel megjelenítése",
    "Show all audio" : "Összes hang megjelenítése",
    "Show all other" : "Összes egyéb megtekintése",
    "Follow conversation settings" : "Beszélgetésbeállítások követése",
    "Group" : "Csoport",
    "Team" : "Csapat",
    "You reconnected to the call" : "Újracsatlakozott a híváshoz",
    "{actor} reconnected to the call" : "{actor} újracsatlakozott a híváshoz",
    "You added {user0} and {user1}" : "Hozzáadta {user0} és {user1} felhasználókat",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Hozzáadta {user0} és {user1} felhasználókat, és még %n résztvevőt","Hozzáadta {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "An administrator added you and {user0}" : "Egy rendszergazda hozzáadta Önt és {user0} felhasználót",
    "{actor} added you and {user0}" : "{actor} hozzáadta Önt és {user0} felhasználót",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Egy rendszergazda hozzáadta Önt, {user0} felhasználót és még %n résztvevőt","Egy rendszergazda hozzáadta Önt, {user0} felhasználót és még %n résztvevőt"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} hozzáadta Önt, {user0} felhasználót és még %n résztvevőt","{actor} hozzáadta Önt, {user0} felhasználót és még %n résztvevőt"],
    "An administrator added {user0} and {user1}" : "Egy rendszergazda hozzáadta {user0} és {user1} felhasználókat",
    "{actor} added {user0} and {user1}" : "{actor} hozzáadta {user0} és {user1} felhasználót",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Egy rendszergazda hozzáadta {user0} és {user1} felhasználókat, és még %n résztvevőt","Egy rendszergazda hozzáadta {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} hozzáadta {user0} és {user1} felhasználókat, és még %n résztvevőt","{actor} hozzáadta {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "You removed {user0} and {user1}" : "Eltávolította {user0} és {user1} felhasználókat",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Eltávolította {user0} és {user1} felhasználókat, és még %n résztvevőt","Eltávolította {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "An administrator removed you and {user0}" : "Egy rendszergazda eltávolította Önt és {user0} felhasználót",
    "{actor} removed you and {user0}" : "{actor} eltávolította Önt és {user0} felhasználót",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Egy rendszergazda eltávolította Önt, {user0} felhasználót és még %n résztvevőt","Egy rendszergazda eltávolította Önt, {user0} felhasználót és még %n résztvevőt"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} eltávolította Önt, {user0} felhasználót és még %n résztvevőt","{actor} eltávolította Önt, {user0} felhasználót és még %n résztvevőt"],
    "An administrator removed {user0} and {user1}" : "Egy rendszergazda eltávolította {user0} és {user1} felhasználót",
    "{actor} removed {user0} and {user1}" : "{actor} eltávolította {user0} és {user1} felhasználót",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Egy rendszergazda eltávolította {user0} és {user1} felhasználókat, és még %n résztvevőt","Egy rendszergazda eltávolította {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} eltávolította {user0} és {user1} felhasználókat, és még %n résztvevőt","{actor} eltávolította {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "You and {user0} joined the call" : "Ön és {user0} csatlakozott a híváshoz",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Ön, {user0} és még %n résztvevő csatlakozott a híváshoz","Ön, {user0} és még %n résztvevő csatlakozott a híváshoz"],
    "{user0} and {user1} joined the call" : "{user0} és {user1} csatlakozott a híváshoz",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} és még %n résztvevő csatlakozott a híváshoz","{user0}, {user1} és még %n résztvevő csatlakozott a híváshoz"],
    "You and {user0} left the call" : "Ön és {user0} kilépett a hívásból",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Ön, {user0} és még %n résztvevő kilépett a hívásból","Ön, {user0} és még %n résztvevő kilépett a hívásból"],
    "{user0} and {user1} left the call" : "{user0} és {user1} kilépett a hívásból",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} és még %n résztvevő kilépett a hívásból","{user0}, {user1} és még %n résztvevő kilépett a hívásból"],
    "You promoted {user0} and {user1} to moderators" : "Moderátorrá léptette elő {user0} és {user1} felhasználókat",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Moderátorrá léptette elő {user0} és {user1} felhasználókat, és még %n résztvevőt","Moderátorrá léptette elő {user0} és {user1} felhasználókat, és még %n résztvevőt"],
    "An administrator promoted you and {user0} to moderators" : "Egy rendszergazda moderátorrá léptette elő Önt és {user0} felhasználót",
    "{actor} promoted you and {user0} to moderators" : "{actor} moderátorrá léptette elő Önt és {user0} felhasználót",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Egy rendszergazda moderátorrá léptette elő Önt, {user0} felhasználót és még %n további résztvevőt","Egy rendszergazda moderátorrá léptette elő Önt, {user0} felhasználót és még %n további résztvevőt"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} moderátorra léptette elő Önt, {user0} felhasználót és még %n résztvevőt","{actor} moderátorra léptette elő Önt, {user0} felhasználót és még %n résztvevőt"],
    "An administrator promoted {user0} and {user1} to moderators" : "Egy rendszergazda moderátorrá léptette elő {user0} és {user1} felhasználókat",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} moderátorrá léptette elő {user0} és {user1} felhasználókat",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Egy rendszergazda moderátorrá léptette elő {user0} és {user1} felhasználókat, valamint még %n résztvevőt","Egy rendszergazda moderátorrá léptette elő {user0} és {user1} felhasználókat, valamint még %n résztvevőt"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} moderátorrá léptette elő {user0} és {user1} felhasználókat, valamint még %n résztvevőt","{actor} moderátorrá léptette elő {user0} és {user1} felhasználókat, valamint még %n résztvevőt"],
    "You demoted {user0} and {user1} from moderators" : "Lefokozta {user0} és {user1} felhasználókat a moderátorok közül",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Lefokozta {user0} és {user1} felhasználókat, valamint még %n résztvevőt a moderátorok közül","Lefokozta {user0} és {user1} felhasználókat, valamint még %n résztvevőt a moderátorok közül"],
    "An administrator demoted you and {user0} from moderators" : "Egy rendszergazda lefokozta Önt és {user0} felhasználót a moderátorok közül",
    "{actor} demoted you and {user0} from moderators" : "{actor} lefokozta Önt és {user0} felhasználót a moderátorok közül",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Egy rendszergazda lefokozta Önt és {user0} felhasználót, valamint még %n résztvevőt a moderátorok közül","Egy rendszergazda lefokozta Önt és {user0} felhasználót, valamint még %n résztvevőt a moderátorok közül"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} lefokozta Önt és {user0} felhasználót, valamint még %n résztvevőt a moderátorok közül","{actor} lefokozta Önt és {user0} felhasználót, valamint még %n résztvevőt a moderátorok közül"],
    "An administrator demoted {user0} and {user1} from moderators" : "Egy rendszegazda lefokozta {user0} és {user1} felhasználókat a moderátorok közül",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} lefokozta {user0} és {user1} felhasználókat a moderátorok közül",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Egy rendszergazda lefokozta {user0} és {user1} felhasználót, valamint még %n résztvevőt a moderátorok közül","Egy rendszergazda lefokozta {user0} és {user1} felhasználót, valamint még %n résztvevőt a moderátorok közül"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} lefokozta {user0} és {user1} felhasználót, valamint még %n résztvevőt a moderátorok közül","{actor} lefokozta {user0} és {user1} felhasználót, valamint még %n résztvevőt a moderátorok közül"],
    "You:" : "Ön:",
    "You: {lastMessage}" : "Ön: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "A kiszolgáló frissítve lett.",
    "(edited by you)" : "(Ön szerkesztette)",
    "(edited by a deleted user)" : "(törölt felhasználó szerkesztette)",
    "(edited by {moderator})" : "({moderator} szerkesztette)",
    "The recording failed. Please contact your administrator." : "A felvétel sikertelen. Lépjen kapcsolatba a rendszergazdával.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Csatlakozni próbál egy beszélgetéshez, miközben aktív munkamenetet folytat egy másik ablakban vagy eszközön. Ezt a Nextcloud Beszélgetés jelenleg nem támogatja. Mit szeretne tenni?",
    "Leave this page" : "Oldal elhagyása",
    "Join here" : "Csatlakozás",
    "Deck card has been posted to {conversation}" : "Kártya lett közzétéve a következőben: {conversation}",
    "An error occurred while posting deck card to conversation" : "Hiba történt a kártya beszélgetésbe küldése során",
    "Post to a conversation" : "Elküldés egy beszélgetésbe",
    "Post to conversation" : "Elküldés egy beszélgetésbe",
    "Location has been posted to {conversation}" : "Hely lett közzétéve a következőben: {conversation}",
    "An error occurred while posting location to conversation" : "Hiba történt a hely beszélgetésbe küldése során",
    "Share to a conversation" : "Megosztás egy beszélgetésben",
    "Share to conversation" : "Megosztás egy beszélgetésben",
    "In conversation" : "Beszélgetésben",
    "Search in conversation: {conversation}" : "Keresés a beszélgetésben: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "A kéréseit a nyers erős támadás elleni védelem fogja vissza",
    "Error while clearing conversation history" : "Hiba a beszélgetés előzményeinek törlése során",
    "Error occurred while allowing guests" : "Hiba történt a vendégek engedélyezése során",
    "Error occurred while disallowing guests" : "Hiba történt a vendégek letiltása során",
    "Error occurred when restricting the conversation to moderator" : "Hiba történt a beszélgetés moderátorra történő korlátozása során",
    "Error occurred when opening the conversation to everyone" : "Hiba történt a beszélgetés mindenki számára történő megnyitása során",
    "Conversation password has been saved" : "A beszélgetés jelszava mentve",
    "Conversation password has been removed" : "A beszélgetés jelszava eltávolítva",
    "Error occurred while saving conversation password" : "Hiba történt a beszélgetés jelszavának mentése során",
    "Call recording is starting." : "A hívásfelvétel elindul.",
    "Call recording stopped while starting." : "A hívásfelvétel leállt az indítása során.",
    "Call recording stopped. You will be notified once the recording is available." : "A hívásfelvétel leállt. Értesítve lesz, amint a felvétel elérhető lesz.",
    "Conversation picture set" : "A beszélgetés képe beállítva",
    "Conversation picture deleted" : "A beszélgetés képe törölve",
    "Could not delete the conversation picture" : "Nem sikerült a beszélgetés képének törlése",
    "Could not remove the automatic expiration" : "Nem sikerült az automatikus lejárat eltávolítása",
    "Could not post message: {errorMessage}" : "Nem sikerült elküldeni az üzenetet: {errorMessage}",
    "Participant is banned successfully" : "A résztvevő sikeresen kitiltva",
    "Error while banning the participant" : "Hiba a résztvevő kitiltása során",
    "An error occurred while fetching the participants" : "Hiba történt a résztvevők letöltése során",
    "Could not send invitation to {actorId}" : "Nem sikerült elküldeni a meghívót a következőnek: {actorId}",
    "Invitations sent" : "Meghívók elküldve",
    "Error occurred when sending invitations" : "Hiba történt a meghívók küldése során",
    "Failed to join the conversation." : "Nem sikerült csatlakozni a beszélgetéshez.",
    "An error occurred while creating breakout rooms" : "Hiba történt a szétbontott szobák létrehozása során",
    "An error occurred while re-ordering the attendees" : "Hiba történt a résztvevők átrendezése során",
    "An error occurred while deleting breakout rooms" : "Hiba történt a szétbontott szobák törlése során",
    "An error occurred while starting breakout rooms" : "Hiba történt a szétbontott szobák indítása során",
    "An error occurred while stopping breakout rooms" : "Hiba történt a szétbontott szobák leállítása során",
    "An error occurred while sending a message to the breakout rooms" : "Hiba történt a szétbontott szobáknak történő üzenetküldés során",
    "An error occurred while requesting assistance" : "Hiba történt a segítségkérés során",
    "An error occurred while resetting the request for assistance" : "Hiba történt a segítségkérés alaphelyzetbe állítása során",
    "An error occurred while joining breakout room" : "Hiba történt a szétbontott szobák összevonása során",
    "Failed to rename the thread" : "Nem sikerült átnevezni a szálat",
    "Error fetching upcoming events" : "Hiba a következő események lekérése során",
    "Error fetching upcoming reminders" : "Hiba a következő emlékeztetők lekérése során",
    "An error occurred while accepting an invitation" : "Hiba történt a meghívás elfogadása során",
    "An error occurred while rejecting an invitation" : "Hiba történt a meghívás elutasítása során",
    "{guest} (guest)" : "{guest} (vendég)",
    "Poll draft has been saved" : "A szavazásvázlat mentve lett",
    "An error occurred while saving the draft" : "Hiba történt a vázlat mentése során",
    "An error occurred while submitting your vote" : "Hiba történt a szavazata leadása során",
    "An error occurred while ending the poll" : "Hiba történt a szavazás befejezése során",
    "An error occurred while deleting the poll draft" : "Hiba történt a szavazásvázlat törlése során",
    "Poll \"{name}\" was created by {user}. Click to vote" : "„{name}” szavazás, létrehozta: {user}. Kattintson a szavazáshoz.",
    "Failed to add reaction" : "A reakció hozzáadása sikertelen",
    "Failed to remove reaction" : "A reakció eltávolítása sikertelen",
    "The server is in maintenance mode." : "A kiszolgáló karbantartási módban van.",
    "Federated server was updated." : "A föderált kiszolgáló frissítve lett.",
    "Error while uploading file \"{fileName}\"" : "Hiba a(z) „{fileName}” fájl feltöltése során",
    "Not enough free space to upload file \"{fileName}\"" : "Nincs elég szabad hely a(z) „{fileName}” fájl feltöltéséhez",
    "You are not allowed to share files" : "Nem oszthat meg fájlokat",
    "Error while sharing file" : "Hiba a fájl megosztása során",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "A Nextcloud Beszélgetés nem támogatja teljes mértékben az Ön által használt böngészőt. Használja a Mozilla Firefox, a Microsoft Edge, a Google Chrome vagy az Apple Safari legújabb verzióját.",
    "_%n hour_::_%n hours_" : ["%n óra","%n óra"],
    "_%n day_::_%n days_" : ["%n nap","%n nap"],
    "_%n week_::_%n weeks_" : ["%n hét","%n hét"],
    "_In %n hour_::_In %n hours_" : ["%n óra múlva","%n óra múlva"],
    "_%n minute _::_%n minutes_" : ["%n perc múlva","%n perc múlva"],
    "In {hours} and {minutes}" : "{hours} és {minutes} múlva",
    "_In %n minute_::_In %n minutes_" : ["%n perc múlva","%n perc múlva"],
    "Later today – {timeLocale}" : "Később a mai nap – {timeLocale}",
    "Set time for later today" : "Idő beállítása későbbre a mai nap",
    "Tomorrow – {timeLocale}" : "Holnap – {timeLocale}",
    "Set time for tomorrow" : "Idő beállítása holnapra",
    "This weekend – {timeLocale}" : "Ez a hétvége – {timeLocale}",
    "Set time for this weekend" : "Idő beállítása a hétvégére",
    "Next week – {timeLocale}" : "Következő hét – {timeLocale}",
    "Set time for next week" : "Idő beállítása a következő hétre",
    "Message link copied to clipboard" : "Az üzenet hivatkozása a vágólapra másolva",
    "Conversation link copied to clipboard" : "A beszélgetési hivatkozás vágólapra másolva",
    "The link could not be copied" : "A hivatkozást nem lehetett másolni",
    "Error while parsing a PROPFIND error" : "Hiba történt a PROPFIND hiba feldolgozása során",
    "Sending signaling message has failed" : "A jelző üzenet küldése sikertelen",
    "Lost connection to signaling server. Trying to reconnect." : "Megszakadt a kapcsolat a jelzőkiszolgálóval. Újracsatlakozás kísérlete.",
    "Lost connection to signaling server." : "Megszakadt a kapcsolat a jelzőkiszolgálóval.",
    "Connecting is taking longer than expected …" : "A kapcsolódás a vártnál tovább tart…",
    "Failed to connect. Retrying …" : "Nem sikerült a csatlakozás. Újrapróbálkozás…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Nem sikerült a csatlakozás. A jelzőkiszolgáló lehet, hogy helytelenül van beállítva.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Frissíteni kell a beállított jelzőkiszolgálót, hogy kompatibilis legyen a Beszélgetés ezen verziójával. Lépjen kapcsolatba a rendszergazdával.",
    "Please restart the app." : "Indítsa újra az alkalmazást.",
    "Please reload the page." : "Frissítse az oldalt.",
    "Please try to restart the app." : "Próbálja meg újraindítani az alkalmazást.",
    "Please try to reload the page." : "Próbálja meg újratölteni az oldalt.",
    "Do not disturb" : "Ne zavarjanak",
    "Away" : "Távol",
    "Microphone {number}" : "{number}. mikrofon",
    "Camera {number}" : "{number}. kamera",
    "Speaker {number}" : "{number}. hangszóró",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Úgy tűnik, hogy némítva beszél, oldja fel a némítást, hogy mások is hallják",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nem sikerült kapcsolatot létesíteni legalább egy résztvevővel. TURN kiszolgálóra lehet szükség a művelethez. Kérje meg a rendszergazdáját, hogy állítson be egyet {linkstart}ezen dokumentáció{linkend} segítségével.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Ez a vártnál hosszabb időt vesz igénybe. A média engedélyeket már megadta (vagy elutasította)? Ha igen, indítsa újra a böngészőt, mivel a hang és a videó meghibásodott",
    "Access to microphone & camera is only possible with HTTPS" : "A mikrofon és a kamera hozzáférése csak HTTPS-en lehetséges",
    "Please move your setup to HTTPS" : "Váltson HTTPS-re",
    "Access to microphone & camera was denied" : "A kamera és a mikrofon hozzáférése letiltva",
    "WebRTC is not supported in your browser" : "A böngészője nem támogatja a WebRTC-t",
    "Please use a different browser like Firefox or Chrome" : "Használjon másik böngészőt, például Firefoxot vagy Chrome-ot",
    "Error while accessing microphone & camera" : "Hiba a kamera és a mikrofon hozzáférésekor",
    "%s Talk on your mobile devices" : "%s Beszélgetés a mobileszközein",
    "Join conversations at any time, anywhere, on any device." : "Csatlakozzon a beszélgetésekhez bármikor, bárhol és bármilyen eszközön.",
    "Android app" : "androidos alkalmazás",
    "iOS app" : "iOS-es alkalmazás",
    "__language_name__" : "Magyar",
    "Webhook Demo" : "Webhook demó",
    "Call summary (%s)" : "Hívásösszesítő (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "A hívásösszesítő bot közzétesz egy áttekintő üzenetet a hívás után, mely felsorolja a résztvevőket és vázolja a feladatokat",
    "Tasks" : "Feladatok",
    "Notes" : "Jegyzetek",
    "Reports" : "Jelentések",
    "Decisions" : "Döntések",
    "Agenda" : "Napirend",
    "Call summary" : "Hívásösszesítő",
    "Call summary - {title}" : "Hívásösszesítő – {title}",
    "Talk to %s" : "Beszélgetés vele: %s",
    "Talk conversation for event" : "Eseményhez tartozó beszélgetés",
    "Client Push is installed, this improves the performance of desktop clients." : "A Kliensleküldés nincs telepítve, ez javítaná az asztali kliensek teljesítményét.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "A {notify_push} nincs telepítve, ez teljesítményproblémákhoz vezethet az asztali kliensek használatakor.",
    "Next meeting" : "Következő találkozó",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Ütemezzen egy találkozót a naptárából. A beszélgetést kell megjelölni helyszínként, hogy megjelenjen itt.",
    "Join conversations from remote Nextcloud servers" : "Csatlakozás távoli Nextcloud-kiszolgálókon lévő beszélgetésekhez",
    "Your default media state has been saved" : "Az alapértelmezett médiaállapot mentve lett",
    "Set reminder for later today" : "Emlékeztető beállítása a mai napon későbbre",
    "Set reminder for tomorrow" : "Emlékeztető beállítása holnapra",
    "Set reminder for this weekend" : "Emlékeztető beállítása erre a hétvégére",
    "Set reminder for next week" : "Emlékeztető beállítása a következő hétre",
    "Generate summary" : "Összefoglaló előállítása",
    "Open poll • You voted already" : "Nyílt szavazás • Már szavazott",
    "Open poll • Click to vote" : "Nyílt szavazás • Kattintson a szavazáshoz",
    "Poll • Ended" : "Szavazás • Véget ért",
    "Talk recording from {time} ({conversation})" : "Beszélgetés felvétele ekkorról: {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Szavazás eredménye • %n szavazat","Szavazás eredménye • %n szavazat"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Nyílt szavazás • %n szavazat","Nyílt szavazás • %n szavazat"],
    "Submit vote" : "Szavazat leadása",
    "Your privacy setting has been saved" : "Az adatvédelmi beállítások mentve",
    "Your personal setting has been saved" : "A személyes beállítása mentve lett",
    "Failed to save sounds setting" : "Nem sikerült menteni a hangbeállításokat",
    "Sounds setting saved" : "Hangbeállítás mentve",
    "Always shown if recording consent is required" : "Mindig megjelenik, ha felvételi hozzájárulás szükséges",
    "Nextcloud Talk was updated, you cannot start or join a call." : "A Nextcloud Beszélgetés frissítve lett, nem indíthat vagy csatlakozhat híváshoz.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Csatlakozott a beszélgetéshez egy másik ablakban vagy eszközön. Ezt a Nextcloud Beszélgetés jelenleg nem támogatja, ezért ezt a munkamenetet lezárták.",
    "Nextcloud Talk was updated." : "A Nextcloud Beszélgetés frissítve lett.",
    "Nextcloud is in maintenance mode." : "A Nextcloud karbantartási módban van.",
    "Nextcloud Talk Federation was updated." : "A Nextcloud Beszélgetés föderációja frissült.",
    "Enable live translation" : "Élő fordítás bekapcsolása",
    "I picked list style" : "A listastílust választottam",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Hé! A Beszélgetést listastílussal vagy üzenetbuborékokkal használod?"
},
"nplurals=2; plural=(n != 1);");
